@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: build_store.c 1287 2014-04-27 20:51:08Z tszilagyi $
+    $Id$
 */
 
 #include <config.h>
@@ -237,8 +237,8 @@ typedef struct {
 
 typedef struct {
 
-	AQUALUNG_THREAD_DECLARE(thread_id);
-	AQUALUNG_MUTEX_DECLARE(mutex);
+	AQUALUNG_THREAD_DECLARE(thread_id)
+	AQUALUNG_MUTEX_DECLARE(mutex)
 
 	int type;
 
@@ -488,7 +488,7 @@ capitalize_new() {
 	model->low_enabled = TRUE;
 	model->mode = CAP_ALL_WORDS;
 
-	strncpy(model->pattern, "CD,a),b),c),d),I,II,III,IV,V,VI,VII,VIII,IX,X", MAXLEN-1);
+	arr_strlcpy(model->pattern, "CD,a),b),c),d),I,II,III,IV,V,VI,VII,VIII,IX,X");
 
 	return model;
 }
@@ -519,7 +519,7 @@ capitalize_load(xmlDocPtr doc, xmlNodePtr node, char * nodeID, capitalize_t ** m
 			xml_load_int(doc, cur, "pre_enabled", &(*model)->pre_enabled);
 			xml_load_int(doc, cur, "low_enabled", &(*model)->low_enabled);
 			xml_load_int(doc, cur, "mode", &(*model)->mode);
-			xml_load_str(doc, cur, "pattern", (*model)->pattern);
+			xml_load_str(doc, cur, "pattern", (*model)->pattern, CHAR_ARRAY_SIZE((*model)->pattern));
 		}
 	}
 }
@@ -650,7 +650,7 @@ capitalize_gui_sync(capitalize_gui_t * gui) {
 	gui->model->low_enabled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(gui->check_low));
 
 	gui->model->mode = gtk_combo_box_get_active(GTK_COMBO_BOX(gui->combo));
-	strncpy(gui->model->pattern, gtk_entry_get_text(GTK_ENTRY(gui->entry_pre)), MAXLEN-1);
+	arr_strlcpy(gui->model->pattern, gtk_entry_get_text(GTK_ENTRY(gui->entry_pre)));
 
 	gui->model->pre_stringv =
 		g_strsplit(gtk_entry_get_text(GTK_ENTRY(gui->entry_pre)), ",", 0);
@@ -703,8 +703,8 @@ file_transform_load(xmlDocPtr doc, xmlNodePtr node, char * nodeID, file_transfor
 
 		for (cur = node->xmlChildrenNode; cur != NULL; cur = cur->next) {
 
-			xml_load_str(doc, cur, "regexp", (*model)->regexp);
-			xml_load_str(doc, cur, "replacement", (*model)->replacement);
+			xml_load_str(doc, cur, "regexp", (*model)->regexp, CHAR_ARRAY_SIZE((*model)->regexp));
+			xml_load_str(doc, cur, "replacement", (*model)->replacement, CHAR_ARRAY_SIZE((*model)->replacement));
 
 			xml_load_int(doc, cur, "rm_number", &(*model)->rm_number);
 			xml_load_int(doc, cur, "rm_extension", &(*model)->rm_extension);
@@ -816,8 +816,8 @@ file_transform_gui_sync(file_transform_gui_t * gui) {
 	gui->model->us_to_space = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(gui->check_us_to_space));
 	gui->model->rm_multi_spaces = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(gui->check_rm_multi_spaces));
 
-	strncpy(gui->model->regexp, gtk_entry_get_text(GTK_ENTRY(gui->entry_regexp)), MAXLEN-1);
-	strncpy(gui->model->replacement, gtk_entry_get_text(GTK_ENTRY(gui->entry_replacement)), MAXLEN-1);
+	arr_strlcpy(gui->model->regexp, gtk_entry_get_text(GTK_ENTRY(gui->entry_regexp)));
+	arr_strlcpy(gui->model->replacement, gtk_entry_get_text(GTK_ENTRY(gui->entry_replacement)));
 
 	gtk_widget_hide(gui->label_error);
 
@@ -881,57 +881,57 @@ build_store_new(GtkTreeIter * store_iter, char * file) {
 
 #ifdef HAVE_SNDFILE
 	for (i = 0; valid_extensions_sndfile[i] != NULL; i++) {
-		strcat(data->incl_pattern, "*.");
-		strcat(data->incl_pattern, valid_extensions_sndfile[i]);
-		strcat(data->incl_pattern, ",");
+		arr_strlcat(data->incl_pattern, "*.");
+		arr_strlcat(data->incl_pattern, valid_extensions_sndfile[i]);
+		arr_strlcat(data->incl_pattern, ",");
 	}
 #endif /* HAVE_SNDFILE */
 
 #ifdef HAVE_FLAC
-	strcat(data->incl_pattern, "*.flac,");
+	arr_strlcat(data->incl_pattern, "*.flac,");
 #endif /* HAVE_FLAC */
 
 #ifdef HAVE_VORBIS
-	strcat(data->incl_pattern, "*.ogg,");
+	arr_strlcat(data->incl_pattern, "*.ogg,");
 #endif /* HAVE_VORBIS */
 
 #ifdef HAVE_MPEG
 	for (i = 0; valid_extensions_mpeg[i] != NULL; i++) {
-		strcat(data->incl_pattern, "*.");
-		strcat(data->incl_pattern, valid_extensions_mpeg[i]);
-		strcat(data->incl_pattern, ",");
+		arr_strlcat(data->incl_pattern, "*.");
+		arr_strlcat(data->incl_pattern, valid_extensions_mpeg[i]);
+		arr_strlcat(data->incl_pattern, ",");
 	}
 #endif /* HAVE_MPEG */
 
 #ifdef HAVE_SPEEX
-	strcat(data->incl_pattern, "*.spx,");
+	arr_strlcat(data->incl_pattern, "*.spx,");
 #endif /* HAVE_SPEEX */
 
 #ifdef HAVE_MPC
-	strcat(data->incl_pattern, "*.mpc,");
+	arr_strlcat(data->incl_pattern, "*.mpc,");
 #endif /* HAVE_MPC */
 
 #ifdef HAVE_MAC
-	strcat(data->incl_pattern, "*.ape,");
+	arr_strlcat(data->incl_pattern, "*.ape,");
 #endif /* HAVE_MAC */
 
 #ifdef HAVE_MOD
 	for (i = 0; valid_extensions_mod[i] != NULL; i++) {
-		strcat(data->incl_pattern, "*.");
-		strcat(data->incl_pattern, valid_extensions_mod[i]);
-		strcat(data->incl_pattern, ",");
+		arr_strlcat(data->incl_pattern, "*.");
+		arr_strlcat(data->incl_pattern, valid_extensions_mod[i]);
+		arr_strlcat(data->incl_pattern, ",");
 	}
 #endif /* HAVE_MOD */
 
 #ifdef HAVE_WAVPACK
-	strcat(data->incl_pattern, "*.wv,");
+	arr_strlcat(data->incl_pattern, "*.wv,");
 #endif /* HAVE_WAVPACK */
 
 	if ((pfilter = strrchr(data->incl_pattern, ',')) != NULL) {
 		*pfilter = '\0';
 	}
 
-	strcpy(data->excl_pattern, "*.jpg,*.jpeg,*.png,*.gif,*.pls,*.m3u,*.cue,*.xml,*.html,*.htm,*.txt,*.ini,*.nfo");
+	arr_strlcpy(data->excl_pattern, "*.jpg,*.jpeg,*.png,*.gif,*.pls,*.m3u,*.cue,*.xml,*.html,*.htm,*.txt,*.ini,*.nfo");
 
 	return data;
 }
@@ -1020,12 +1020,12 @@ build_store_load(build_store_t * data, int test_only) {
 		for (cur = node->xmlChildrenNode; cur != NULL; cur = cur->next) {
 
 			xml_load_int(doc, cur, "type", &data->type);
-			xml_load_str(doc, cur, "root", data->root);
+			xml_load_str(doc, cur, "root", data->root, CHAR_ARRAY_SIZE(data->root));
 			xml_load_int(doc, cur, "artist_dir_depth", &data->artist_dir_depth);
 			xml_load_int(doc, cur, "excl_enabled", &data->excl_enabled);
-			xml_load_str(doc, cur, "excl_pattern", data->excl_pattern);
+			xml_load_str(doc, cur, "excl_pattern", data->excl_pattern, CHAR_ARRAY_SIZE(data->excl_pattern));
 			xml_load_int(doc, cur, "incl_enabled", &data->incl_enabled);
-			xml_load_str(doc, cur, "incl_pattern", data->incl_pattern);
+			xml_load_str(doc, cur, "incl_pattern", data->incl_pattern, CHAR_ARRAY_SIZE(data->incl_pattern));
 			xml_load_int(doc, cur, "reset_existing_data", &data->reset_existing_data);
 			xml_load_int(doc, cur, "remove_dead_files", &data->remove_dead_files);
 
@@ -1512,7 +1512,7 @@ browse_button_clicked(GtkButton * button, gpointer data) {
 				GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
 				FILE_CHOOSER_FILTER_NONE,
 				(GtkWidget *)data,
-				options.currdir);
+				options.currdir, CHAR_ARRAY_SIZE(options.currdir));
 }
 
 
@@ -1531,7 +1531,7 @@ snd_button_test_clicked(GtkWidget * widget, gpointer user_data) {
 	}
 
 	buf[0] = '\0';
-	strncpy(buf, (char *)gtk_entry_get_text(GTK_ENTRY(data->snd_entry_input)), MAXLEN-1);
+	arr_strlcpy(buf, gtk_entry_get_text(GTK_ENTRY(data->snd_entry_input)));
 	file_transform(buf, data->snd_file_trans_gui->model);
 
 	regfree(&data->snd_file_trans_gui->model->compiled);
@@ -2078,7 +2078,7 @@ build_dialog(build_store_t * data) {
 			goto display;
 		}
 
-		normalize_filename(proot, data->root);
+		normalize_filename(proot, data->root, CHAR_ARRAY_SIZE(data->root));
 		g_free(proot);
 
 
@@ -2096,8 +2096,8 @@ build_dialog(build_store_t * data) {
 		set_option_from_combo(art_sort_combo, &data->artist_sort_by);
 		set_option_from_combo(rec_sort_combo, &data->record_sort_by);
 
-		set_option_from_entry(gen_entry_excl, data->excl_pattern, MAXLEN);
-		set_option_from_entry(gen_entry_incl, data->incl_pattern, MAXLEN);
+		set_option_from_entry(gen_entry_excl, data->excl_pattern, CHAR_ARRAY_SIZE(data->excl_pattern));
+		set_option_from_entry(gen_entry_incl, data->incl_pattern, CHAR_ARRAY_SIZE(data->incl_pattern));
 
 		set_option_from_toggle(gen_check_excl, &data->excl_enabled);
 		set_option_from_toggle(gen_check_incl, &data->incl_enabled);
@@ -2307,7 +2307,7 @@ void
 set_prog_file_entry(build_store_t * data, char * path) {
 
 	AQUALUNG_MUTEX_LOCK(data->mutex);
-	strncpy(data->path, path, MAXLEN-1);
+	arr_strlcpy(data->path, path);
         AQUALUNG_MUTEX_UNLOCK(data->mutex);
 
 	aqualung_idle_add(set_prog_file_entry_idle, data);
@@ -2331,12 +2331,13 @@ void
 set_prog_action_label(build_store_t * data, char * action) {
 
 	AQUALUNG_MUTEX_LOCK(data->mutex);
-	strncpy(data->action, action, MAXLEN-1);
+	arr_strlcpy(data->action, action);
 	AQUALUNG_MUTEX_UNLOCK(data->mutex);
 
 	aqualung_idle_add(set_prog_action_label_idle, data);
 }
 
+/* XXX This function needs reviewing for string bounds checking */
 void
 file_transform(char * buf, file_transform_t * model) {
 
@@ -2386,13 +2387,13 @@ file_transform(char * buf, file_transform_t * model) {
 		}
 
 		if (!*tmp) {
-			strncpy(tmp, p + offs, MAXLEN-1);
+			arr_strlcpy(tmp, p + offs);
 		} else {
-			strcat(tmp, p + offs);
+			arr_strlcat(tmp, p + offs);
 		}
 
 	} else {
-		strncpy(tmp, buf, MAXLEN-1);
+		arr_strlcpy(tmp, buf);
 	}
 
 
@@ -2633,7 +2634,7 @@ process_meta(build_store_t * data, build_disc_t * disc) {
 			}
 
 			if (metadata_get_title(fdec->meta, &tmp) && !is_all_wspace(tmp)) {
-				strncpy(ptrack->name[DATA_SRC_META], tmp, MAXLEN-1);
+				arr_strlcpy(ptrack->name[DATA_SRC_META], tmp);
 			}
 
 			if (disc->record.year[0] == '\0' &&
@@ -2655,7 +2656,7 @@ process_meta(build_store_t * data, build_disc_t * disc) {
 			    metadata_get_comment(fdec->meta, &tmp) &&
 			    !is_all_wspace(tmp)) {
 
-				strncpy(ptrack->comment, tmp, MAXLEN-1);
+				arr_strlcpy(ptrack->comment, tmp);
 			}
 			file_decoder_close(fdec);
 		}
@@ -2663,15 +2664,15 @@ process_meta(build_store_t * data, build_disc_t * disc) {
 	}
 
 	if (map_artist) {
-		strncpy(disc->artist.name[DATA_SRC_META], map_get_max(map_artist), MAXLEN-1);
+		arr_strlcpy(disc->artist.name[DATA_SRC_META], map_get_max(map_artist));
 	}
 
 	if (map_record) {
-		strncpy(disc->record.name[DATA_SRC_META], map_get_max(map_record), MAXLEN-1);
+		arr_strlcpy(disc->record.name[DATA_SRC_META], map_get_max(map_record));
 	}
 
 	if (map_year) {
-		strncpy(disc->record.year, map_get_max(map_year), MAXLEN-1);
+		arr_strlcpy(disc->record.year, map_get_max(map_year));
 	}
 
 	map_free(map_artist);
@@ -2697,7 +2698,7 @@ add_new_track(GtkTreeIter * record_iter, build_track_t * ptrack, int i) {
 		i = gtk_tree_model_iter_n_children(GTK_TREE_MODEL(music_store), record_iter) + 1;
 	}
 
-	snprintf(sort_name, 15, "%02d", i);
+	arr_snprintf(sort_name, "%02d", i);
 
 	gtk_tree_store_append(music_store, &track_iter, record_iter);
 	gtk_tree_store_set(music_store, &track_iter,
@@ -2927,8 +2928,8 @@ get_file_list(build_store_t * data, char * dir_record, build_disc_t * disc, int
 	n = scandir(dir_record, &ent_track, filter, alphasort);
 	for (i = 0; i < n; i++) {
 
-		strncpy(basename, ent_track[i]->d_name, MAXLEN-1);
-		snprintf(filename, MAXLEN-1, "%s/%s", dir_record, ent_track[i]->d_name);
+		arr_strlcpy(basename, ent_track[i]->d_name);
+		arr_snprintf(filename, "%s/%s", dir_record, ent_track[i]->d_name);
 
 		if (is_dir(filename) || !filter_excl_incl(data, basename)) {
 			free(ent_track[i]);
@@ -2943,10 +2944,10 @@ get_file_list(build_store_t * data, char * dir_record, build_disc_t * disc, int
 				fprintf(stderr, "build_store.c: get_file_list(): calloc error\n");
 				return;
 			} else {
-				strncpy(track->filename, filename, MAXLEN-1);
+				arr_strlcpy(track->filename, filename);
 
 				utf8 = g_filename_display_name(ent_track[i]->d_name);
-				strncpy(track->d_name, utf8, MAXLEN-1);
+				arr_strlcpy(track->d_name, utf8);
 				g_free(utf8);
 
 				track->duration = duration;
@@ -2986,13 +2987,12 @@ process_filename(build_store_t * data, build_disc_t * disc) {
 		if (data->data_src_artist->enabled[i]) {
 
 			if (data->data_src_artist->type[i] == DATA_SRC_FILE) {
-				strncpy(disc->artist.name[DATA_SRC_FILE],
-					disc->artist.d_name, MAXLEN-1);
+				arr_strlcpy(disc->artist.name[DATA_SRC_FILE], disc->artist.d_name);
 			}
 
 			if (disc->artist.name[data->data_src_artist->type[i]][0] != '\0') {
-				strncpy(disc->artist.final,
-					disc->artist.name[data->data_src_artist->type[i]], MAXLEN-1);
+				arr_strlcpy(disc->artist.final,
+					    disc->artist.name[data->data_src_artist->type[i]]);
 				break;
 			}
 		}
@@ -3001,10 +3001,10 @@ process_filename(build_store_t * data, build_disc_t * disc) {
 	if (i == 3) {
 		if (data->type == BUILD_TYPE_STRICT) {
 			char tmp[MAXLEN];
-			snprintf(tmp, MAXLEN-1, "%s (%s)", _("Unknown Artist"), disc->artist.d_name);
-			strncpy(disc->artist.final, tmp, MAXLEN-1);
+			arr_snprintf(tmp, "%s (%s)", _("Unknown Artist"), disc->artist.d_name);
+			arr_strlcpy(disc->artist.final, tmp);
 		} else {
-			strncpy(disc->artist.final, _("Unknown Artist"), MAXLEN-1);
+			arr_strlcpy(disc->artist.final, _("Unknown Artist"));
 		}
 		disc->artist.unknown = 1;
 	} else {
@@ -3023,13 +3023,12 @@ process_filename(build_store_t * data, build_disc_t * disc) {
 		if (data->data_src_record->enabled[i]) {
 
 			if (data->data_src_record->type[i] == DATA_SRC_FILE) {
-				strncpy(disc->record.name[DATA_SRC_FILE],
-					disc->record.d_name, MAXLEN-1);
+				arr_strlcpy(disc->record.name[DATA_SRC_FILE], disc->record.d_name);
 			}
 
 			if(disc->record.name[data->data_src_record->type[i]][0] != '\0') {
-				strncpy(disc->record.final,
-					disc->record.name[data->data_src_record->type[i]], MAXLEN-1);
+				arr_strlcpy(disc->record.final,
+					    disc->record.name[data->data_src_record->type[i]]);
 				break;
 			}
 		}
@@ -3038,10 +3037,10 @@ process_filename(build_store_t * data, build_disc_t * disc) {
 	if (i == 3) {
 		if (data->type == BUILD_TYPE_STRICT) {
 			char tmp[MAXLEN];
-			snprintf(tmp, MAXLEN-1, "%s (%s)", _("Unknown Record"), disc->record.d_name);
-			strncpy(disc->record.final, tmp, MAXLEN-1);
+			arr_snprintf(tmp, "%s (%s)", _("Unknown Record"), disc->record.d_name);
+			arr_strlcpy(disc->record.final, tmp);
 		} else {
-			strncpy(disc->record.final, disc->record.dirname, MAXLEN-1);
+			arr_strlcpy(disc->record.final, disc->record.dirname);
 		}
 		disc->record.unknown = 1;
 	} else {
@@ -3057,27 +3056,26 @@ process_filename(build_store_t * data, build_disc_t * disc) {
 
 	for (i = 0, ptrack = disc->tracks; ptrack; i++, ptrack = ptrack->next) {
 
-		strncpy(ptrack->name[DATA_SRC_FILE], ptrack->d_name, MAXLEN-1);
+		arr_strlcpy(ptrack->name[DATA_SRC_FILE], ptrack->d_name);
 
 		for (j = 0; j < 3; j++) {
 
 			if (data->data_src_track->enabled[j]) {
 
 				if (data->data_src_track->type[i] == DATA_SRC_FILE) {
-					strncpy(ptrack->name[DATA_SRC_FILE],
-						ptrack->d_name, MAXLEN-1);
+					arr_strlcpy(ptrack->name[DATA_SRC_FILE], ptrack->d_name);
 				}
 
 				if (ptrack->name[data->data_src_track->type[j]][0] != '\0') {
-					strncpy(ptrack->final,
-						ptrack->name[data->data_src_track->type[j]], MAXLEN-1);
+					arr_strlcpy(ptrack->final,
+						    ptrack->name[data->data_src_track->type[j]]);
 					break;
 				}
 			}
 		}
 
 		if (j == 3) {
-			strncpy(ptrack->final, ptrack->d_name, MAXLEN-1);
+			arr_strlcpy(ptrack->final, ptrack->d_name);
 		} else {
 			file_transform(ptrack->final, data->file_transform_track);
 
@@ -3092,55 +3090,55 @@ process_filename(build_store_t * data, build_disc_t * disc) {
 
 	switch (data->artist_sort_by) {
 	case SORT_NAME:
-		strncpy(disc->artist.sort, disc->artist.final, MAXLEN-1);
+		arr_strlcpy(disc->artist.sort, disc->artist.final);
 		break;
 	case SORT_NAME_LOW:
 		utf8 = g_utf8_strdown(disc->artist.final, -1);
-		strncpy(disc->artist.sort, utf8, MAXLEN-1);
+		arr_strlcpy(disc->artist.sort, utf8);
 		g_free(utf8);
 		break;
 	case SORT_DIR:
-		strncpy(disc->artist.sort, disc->artist.d_name, MAXLEN-1);
+		arr_strlcpy(disc->artist.sort, disc->artist.d_name);
 		break;
 	case SORT_DIR_LOW:
 		utf8 = g_utf8_strdown(disc->artist.d_name, -1);
-		strncpy(disc->artist.sort, utf8, MAXLEN-1);
+		arr_strlcpy(disc->artist.sort, utf8);
 		g_free(utf8);
 		break;
 	}
 
 	if (disc->artist.unknown) {
 		char tmp[MAXLEN];
-		snprintf(tmp, MAXLEN-1, "0 %s", disc->artist.sort);
-		strncpy(disc->artist.sort, tmp, MAXLEN-1);
+		arr_snprintf(tmp, "0 %s", disc->artist.sort);
+		arr_strlcpy(disc->artist.sort, tmp);
 	}
 
 	switch (data->record_sort_by) {
 	case SORT_YEAR:
-		strncpy(disc->record.sort, disc->record.year, MAXLEN-1);
+		arr_strlcpy(disc->record.sort, disc->record.year);
 		break;
 	case SORT_NAME:
-		strncpy(disc->record.sort, disc->record.final, MAXLEN-1);
+		arr_strlcpy(disc->record.sort, disc->record.final);
 		break;
 	case SORT_NAME_LOW:
 		utf8 = g_utf8_strdown(disc->record.final, -1);
-		strncpy(disc->record.sort, utf8, MAXLEN-1);
+		arr_strlcpy(disc->record.sort, utf8);
 		g_free(utf8);
 		break;
 	case SORT_DIR:
-		strncpy(disc->record.sort, disc->record.d_name, MAXLEN-1);
+		arr_strlcpy(disc->record.sort, disc->record.d_name);
 		break;
 	case SORT_DIR_LOW:
 		utf8 = g_utf8_strdown(disc->record.d_name, -1);
-		strncpy(disc->record.sort, utf8, MAXLEN-1);
+		arr_strlcpy(disc->record.sort, utf8);
 		g_free(utf8);
 		break;
 	}
 
 	if (disc->record.unknown) {
 		char tmp[MAXLEN];
-		snprintf(tmp, MAXLEN-1, "0 %s", disc->record.sort);
-		strncpy(disc->record.sort, tmp, MAXLEN-1);
+		arr_snprintf(tmp, "0 %s", disc->record.sort);
+		arr_strlcpy(disc->record.sort, tmp);
 	}
 }
 
@@ -3191,11 +3189,11 @@ process_record(build_store_t * data, char * dir_record, char * artist_d_name, ch
 	}
 
 	utf8 = g_filename_display_name(artist_d_name);
-	strncpy(disc->artist.d_name, utf8, MAXLEN-1);
+	arr_strlcpy(disc->artist.d_name, utf8);
 	g_free(utf8);
 
 	utf8 = g_filename_display_name(record_d_name);
-	strncpy(disc->record.d_name, utf8, MAXLEN-1);
+	arr_strlcpy(disc->record.d_name, utf8);
 	g_free(utf8);
 
 
@@ -3267,22 +3265,24 @@ process_record(build_store_t * data, char * dir_record, char * artist_d_name, ch
 			}
 		}
 
-		cddb_query_batch(ntracks, frames, length, artist, record, &year, tracks);
+		cddb_query_batch(ntracks, frames, length,
+				 artist, CHAR_ARRAY_SIZE(artist), record, CHAR_ARRAY_SIZE(record),
+				 &year, tracks, MAXLEN);
 
 		if (artist[0] != '\0') {
-			strncpy(disc->artist.name[DATA_SRC_CDDB], artist, MAXLEN-1);
+			arr_strlcpy(disc->artist.name[DATA_SRC_CDDB], artist);
 		}
 
 		if (record[0] != '\0') {
-			strncpy(disc->record.name[DATA_SRC_CDDB], record, MAXLEN-1);
+			arr_strlcpy(disc->record.name[DATA_SRC_CDDB], record);
 		}
 
 		if (year > 0) {
-			snprintf(disc->record.year, MAXLEN-1, "%d", year);
+			arr_snprintf(disc->record.year, "%d", year);
 		}
 
 		for (i = 0, ptrack = disc->tracks; ptrack && i < ntracks; i++, ptrack = ptrack->next) {
-			strncpy(ptrack->name[DATA_SRC_CDDB], tracks[i], MAXLEN-1);
+			arr_strlcpy(ptrack->name[DATA_SRC_CDDB], tracks[i]);
 			free(tracks[i]);
 		}
 
@@ -3296,7 +3296,7 @@ process_record(build_store_t * data, char * dir_record, char * artist_d_name, ch
 
 
 	if (data->rec_add_year_to_comment) {
-		strncpy(disc->record.comment, disc->record.year, MAXLEN-1);
+		arr_strlcpy(disc->record.comment, disc->record.year);
 	}
 
 
@@ -3343,16 +3343,16 @@ process_track(build_store_t * data, char * filename, char * d_name, float durati
 		char * utf8;
 
 		utf8 = g_filename_display_name(d_name);
-		strncpy(disc->tracks->d_name, utf8, MAXLEN-1);
-		strncpy(disc->record.d_name, utf8, MAXLEN-1);
-		strncpy(disc->artist.d_name, utf8, MAXLEN-1);
+		arr_strlcpy(disc->tracks->d_name, utf8);
+		arr_strlcpy(disc->record.d_name, utf8);
+		arr_strlcpy(disc->artist.d_name, utf8);
 		g_free(utf8);
 
 		utf8 = g_filename_display_name(filename);
-		strncpy(disc->record.dirname, g_path_get_dirname(utf8), MAXLEN-1);
+		arr_strlcpy(disc->record.dirname, g_path_get_dirname(utf8));
 		g_free(utf8);
 
-		strncpy(disc->tracks->filename, filename, MAXLEN-1);
+		arr_strlcpy(disc->tracks->filename, filename);
 		disc->tracks->duration = duration;
 		disc->tracks->rva = 1.0f;
 		disc->tracks->rva_found = 0;
@@ -3378,7 +3378,7 @@ process_track(build_store_t * data, char * filename, char * d_name, float durati
 
 
 	if (data->rec_add_year_to_comment) {
-		strncpy(disc->record.comment, disc->record.year, MAXLEN-1);
+		arr_strlcpy(disc->record.comment, disc->record.year);
 	}
 
 
@@ -3418,7 +3418,7 @@ scan_artist_record(build_store_t * data, char * dir_artist, char * name_artist,
 			break;
 		}
 
-		snprintf(dir_record, MAXLEN-1, "%s/%s", dir_artist, ent_record[i]->d_name);
+		arr_snprintf(dir_record, "%s/%s", dir_artist, ent_record[i]->d_name);
 
 		if (!is_dir(dir_record)) {
 			free(ent_record[i]);
@@ -3485,7 +3485,7 @@ scan_recursively(build_store_t * data, char * dir) {
 			break;
 		}
 
-		snprintf(path, MAXLEN-1, "%s/%s", dir, ent[i]->d_name);
+		arr_snprintf(path, "%s/%s", dir, ent[i]->d_name);
 
 		if (is_dir(path)) {
 			scan_recursively(data, path);
