@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: cd_ripper.c 1286 2014-04-27 20:50:41Z tszilagyi $
+    $Id$
 */
 
 #include <config.h>
@@ -177,12 +177,12 @@ ripper_source_write_back(GtkTreeIter * record_iter, char * artist, char * record
 	gtk_tree_model_get(GTK_TREE_MODEL(music_store), record_iter, MS_COL_DATA, &drive, -1);
 	disc = &drive->disc;
 
-	strncpy(disc->artist_name, artist, MAXLEN-1);
-	strncpy(disc->record_name, record, MAXLEN-1);
-	strncpy(disc->genre, genre, MAXLEN-1);
+	arr_strlcpy(disc->artist_name, artist);
+	arr_strlcpy(disc->record_name, record);
+	arr_strlcpy(disc->genre, genre);
 	disc->year = year;
 
-	snprintf(tmp, MAXLEN-1, "%s: %s", artist, record);
+	arr_snprintf(tmp, "%s: %s", artist, record);
 	gtk_tree_store_set(music_store, record_iter, MS_COL_NAME, tmp, -1);
 	
 
@@ -243,7 +243,7 @@ ripper_destdir_browse_cb(GtkButton * button, gpointer data) {
 				GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
 				FILE_CHOOSER_FILTER_NONE,
 				(GtkWidget *)data,
-				options.ripdir);
+				options.ripdir, CHAR_ARRAY_SIZE(options.ripdir));
 }
 
 
@@ -398,11 +398,11 @@ ripper_bitrate_changed(GtkRange * range, gpointer data) {
 		switch (i) {
 		case 0:
 		case 8:
-			snprintf(str, 255, "%d (%s)", i, (i == 0) ? _("fast") : _("best"));
+			arr_snprintf(str, "%d (%s)", i, (i == 0) ? _("fast") : _("best"));
 			gtk_label_set_text(GTK_LABEL(ripper_bitrate_value_label), str);
 			break;
 		default:
-			snprintf(str, 255, "%d", i);
+			arr_snprintf(str, "%d", i);
 			gtk_label_set_text(GTK_LABEL(ripper_bitrate_value_label), str);
 			break;
 		}
@@ -410,7 +410,7 @@ ripper_bitrate_changed(GtkRange * range, gpointer data) {
 	if (strcmp(text, "Ogg Vorbis") == 0) {
 		int i = (int)val;
 		char str[256];
-		snprintf(str, 255, "%d", i);
+		arr_snprintf(str, "%d", i);
 		gtk_label_set_text(GTK_LABEL(ripper_bitrate_value_label), str);
 	}
 	if (strcmp(text, "MP3") == 0) {
@@ -419,7 +419,7 @@ ripper_bitrate_changed(GtkRange * range, gpointer data) {
 #ifdef HAVE_LAME
 		i = lame_encoder_validate_bitrate(i, 0);
 #endif /* HAVE_LAME */
-		snprintf(str, 255, "%d", i);
+		arr_snprintf(str, "%d", i);
 		gtk_label_set_text(GTK_LABEL(ripper_bitrate_value_label), str);
 	}
 	g_free(text);
@@ -570,7 +570,7 @@ ripper_make_dest_iters(GtkTreeIter * store_iter,
 		}
 
 		record_data->year = ripper_year;
-		snprintf(str_year, 15, "%d", ripper_year);
+		arr_snprintf(str_year, "%d", ripper_year);
 
                 gtk_tree_store_append(music_store, record_iter, artist_iter);
                 gtk_tree_store_set(music_store, record_iter,
@@ -609,7 +609,7 @@ ripper_make_dest_iters(GtkTreeIter * store_iter,
         }
 
 	record_data->year = ripper_year;
-	snprintf(str_year, 15, "%d", ripper_year);
+	arr_snprintf(str_year, "%d", ripper_year);
 
         gtk_tree_store_append(music_store, record_iter, artist_iter);
         gtk_tree_store_set(music_store, record_iter,
@@ -865,7 +865,7 @@ cd_ripper_dialog(cdda_drive_t * drive, GtkTreeIter * iter) {
                         goto ripper_display;
                 }
 
-		normalize_filename(pdestdir, destdir);
+		normalize_filename(pdestdir, destdir, CHAR_ARRAY_SIZE(destdir));
 		g_free(pdestdir);
 
 		if (access(destdir, R_OK | W_OK) != 0) {
@@ -881,16 +881,16 @@ cd_ripper_dialog(cdda_drive_t * drive, GtkTreeIter * iter) {
 			goto ripper_display;
 		}
 
-		strncpy(options.ripdir, destdir, MAXLEN-1);
+		arr_strlcpy(options.ripdir, destdir);
 		options.cdrip_file_format = ripper_format = get_ripper_format();
 		options.cdrip_bitrate = ripper_bitrate = gtk_range_get_value(GTK_RANGE(ripper_bitrate_scale));
 		set_option_from_toggle(ripper_vbr_check, &ripper_vbr);
 		options.cdrip_vbr = ripper_vbr;
 		set_option_from_toggle(ripper_meta_check, &ripper_meta);
 		options.cdrip_metadata = ripper_meta;
-		set_option_from_entry(ripper_artist_entry, ripper_artist, MAXLEN);
-		set_option_from_entry(ripper_album_entry, ripper_album, MAXLEN);
-		set_option_from_entry(ripper_genre_entry, ripper_genre, MAXLEN);
+		set_option_from_entry(ripper_artist_entry, ripper_artist, CHAR_ARRAY_SIZE(ripper_artist));
+		set_option_from_entry(ripper_album_entry, ripper_album, CHAR_ARRAY_SIZE(ripper_album));
+		set_option_from_entry(ripper_genre_entry, ripper_genre, CHAR_ARRAY_SIZE(ripper_genre));
 		set_option_from_spin(ripper_year_spinner, &ripper_year);
 		ripper_write_to_store = get_ripper_deststore_iter(&ripper_dest_store);
 
@@ -921,7 +921,7 @@ cd_ripper_dialog(cdda_drive_t * drive, GtkTreeIter * iter) {
 
 
 void
-sector_to_str(int sector, char * str) {
+sector_to_str(int sector, char * str, size_t str_len) {
 
 	int m, s, f;
 
@@ -929,7 +929,7 @@ sector_to_str(int sector, char * str) {
 	s = sector / 75 - m * 60;
 	f = sector % 75;
 
-	snprintf(str, MAXLEN-1, "%d [%02d:%02d.%02d]", sector, m, s, f);
+	snprintf(str, str_len, "%d [%02d:%02d.%02d]", sector, m, s, f);
 }
 
 
@@ -956,9 +956,9 @@ ripper_prog_store_make(cdda_drive_t * drive) {
 
 		len = drive->disc.toc[n] - drive->disc.toc[n-1];
 		total_sectors += len;
-		sector_to_str(drive->disc.toc[n-1], begin);
-		sector_to_str(len, length);
-		sprintf(num, "%d.", n);
+		sector_to_str(drive->disc.toc[n-1], begin, CHAR_ARRAY_SIZE(begin));
+		sector_to_str(len, length, CHAR_ARRAY_SIZE(length));
+		arr_snprintf(num, "%d.", n);
 
 		gtk_list_store_append(ripper_prog_store, &iter);
 		gtk_list_store_set(ripper_prog_store, &iter,
@@ -969,7 +969,7 @@ ripper_prog_store_make(cdda_drive_t * drive) {
 				   -1);
 	}
 
-	sector_to_str(total_sectors, length);
+	sector_to_str(total_sectors, length, CHAR_ARRAY_SIZE(length));
 	
 	gtk_list_store_append(ripper_prog_store, &iter);
 	gtk_list_store_set(ripper_prog_store, &iter,
@@ -1117,7 +1117,7 @@ ripper_update_status(gpointer pdata) {
 	if (!ripper_prog_window_visible) {
 		char title[MAXLEN];
 
-		snprintf(title, MAXLEN, "%d%% - %s", prog_total, _("Ripping CD tracks"));
+		arr_snprintf(title, "%d%% - %s", prog_total, _("Ripping CD tracks"));
 		gtk_window_set_title(GTK_WINDOW(ripper_prog_window), title);
 	}
 
@@ -1227,8 +1227,8 @@ ripper_thread(void * arg) {
 			break;
 		}
 
-		snprintf(decoder_filename, 255, "CDDA %s %lX %d", drive->device_path, hash, no);
-		snprintf(mode.filename, MAXLEN-1, "%s/track%02d.%s", destdir, no, ext);
+		arr_snprintf(decoder_filename, "CDDA %s %lX %d", drive->device_path, hash, no);
+		arr_snprintf(mode.filename, "%s/track%02d.%s", destdir, no, ext);
 		mode.file_lib = ripper_format;
 		mode.sample_rate = 44100;
 		mode.channels = 2;
@@ -1244,7 +1244,7 @@ ripper_thread(void * arg) {
 		if (mode.write_meta) {
 			mode.meta = metadata_new();
 			char date[8];
-			snprintf(date, 7, "%d", ripper_year);
+			arr_snprintf(date, "%d", ripper_year);
 
 			ripper_meta_add(mode.meta, tags, META_FIELD_ARTIST, ripper_artist, 0);
 			ripper_meta_add(mode.meta, tags, META_FIELD_ALBUM, ripper_album, 0);
@@ -1307,7 +1307,7 @@ ripper_thread(void * arg) {
 			track_data->duration = track_sectors_read / 75.0;
 			track_data->volume = 1.0f;
 
-			snprintf(sort_name, 3, "%02d", no);
+			arr_snprintf(sort_name, "%02d", no);
 
 			gtk_tree_store_append(music_store, &iter, &ripper_dest_record);
 			gtk_tree_store_set(music_store, &iter,
