@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: cdda.c 1287 2014-04-27 20:51:08Z tszilagyi $
+    $Id$
 */
 
 #include <config.h>
@@ -186,22 +186,21 @@ cdda_get_drive_by_spec_device_path(char * device_path) {
 }
 
 
-/* value should point to a buffer of size at least CDDA_MAXLEN */
 /* ret 0 if OK, -1 if readlink error */
 #ifndef _WIN32
 int
-symlink_deref_absolute(char * symlink, char * path) {
+symlink_deref_absolute(char * symlink, char * path, size_t path_size) {
 
-	int ret = readlink(symlink, path, CDDA_MAXLEN-1);
-	if (ret < 0)
+	int ret = readlink(symlink, path, path_size);
+	if (ret < 0 || ret == path_size)
 		return -1;
 	path[ret] = '\0';
 	
 	if (!g_path_is_absolute(path)) {
 		char tmp[CDDA_MAXLEN];
 		char * dir = g_path_get_dirname(symlink);
-		snprintf(tmp, CDDA_MAXLEN-1, "%s/%s", dir, path);
-		strcpy(path, tmp);
+		arr_snprintf(tmp, "%s/%s", dir, path);
+		g_strlcpy(path, tmp, path_size);
 		g_free(dir);
 	}
 	return 0;
@@ -223,7 +222,7 @@ cdda_skip_extra_symlink(char ** drives, int i) {
 	if (!g_file_test(drives[i], G_FILE_TEST_IS_SYMLINK))
 		return 0;
 
-	if ((symlink_deref_absolute(drives[i], path)) != 0)
+	if ((symlink_deref_absolute(drives[i], path, CHAR_ARRAY_SIZE(path))) != 0)
 		return 1;
 
 	/* have the destination of the symlink in our device list */
@@ -240,7 +239,7 @@ cdda_skip_extra_symlink(char ** drives, int i) {
 		char path2[CDDA_MAXLEN];
 		if (!g_file_test(drives[j], G_FILE_TEST_IS_SYMLINK))
 			continue;
-		if ((symlink_deref_absolute(drives[j], path2)) != 0)
+		if ((symlink_deref_absolute(drives[j], path2, CHAR_ARRAY_SIZE(path2))) != 0)
 			continue;
 		if (strcmp(path, path2) == 0)
 			return 1;
@@ -313,7 +312,7 @@ cdda_scan_drive(char * device_path, cdda_drive_t * cdda_drive) {
 		if (!cdda_drive->cdio) {
 			return -1;
 		}		
-		strncpy(cdda_drive->device_path, device_path, CDDA_MAXLEN-1);
+		arr_strlcpy(cdda_drive->device_path, device_path);
 	}
 	
 	cdda_drive->disc.n_tracks = 0;
@@ -368,8 +367,8 @@ cdda_scan_drive(char * device_path, cdda_drive_t * cdda_drive) {
 	cdda_drive->disc.hash = calc_cdda_hash(&cdda_drive->disc);
 
 	if (cdda_drive->disc.hash != cdda_drive->disc.hash_prev) {
-		strncpy(cdda_drive->disc.artist_name, _("Unknown Artist"), MAXLEN-1);
-		strncpy(cdda_drive->disc.record_name, _("Unknown Record"), MAXLEN-1);
+		arr_strlcpy(cdda_drive->disc.artist_name, _("Unknown Artist"));
+		arr_strlcpy(cdda_drive->disc.record_name, _("Unknown Record"));
 
 		cdda_drive->swap_bytes = -1; /* unknown */
 	}
@@ -620,14 +619,14 @@ update_track_data_from_cdtext(cdda_drive_t * drive, GtkTreeIter * iter_drive) {
 
 		performer = cdda_get_cdtext(cdio, CDTEXT_FIELD_PERFORMER, i);
 		if (performer && *performer != '\0') {
-			g_strlcpy(drive->disc.artist_name, performer, MAXLEN);
+			arr_strlcpy(drive->disc.artist_name, performer);
 		} else {
 			ret = 1;
 		}
 
 		title = cdda_get_cdtext(cdio, CDTEXT_FIELD_TITLE, i);
 		if (title && *title != '\0') {
-			g_strlcpy(drive->disc.record_name, title, MAXLEN);
+			arr_strlcpy(drive->disc.record_name, title);
 		} else {
 			ret = 1;
 		}
@@ -674,9 +673,9 @@ update_track_data(cdda_drive_t * drive, GtkTreeIter iter_drive) {
 
 		cdda_track_t * data;
 
-		snprintf(title, MAXLEN-1, "Track %d", i+1);
-		snprintf(path, CDDA_MAXLEN-1, "CDDA %s %lX %d", drive->device_path, drive->disc.hash, i+1);
-		snprintf(sort, 15, "%02d", i+1);
+		arr_snprintf(title, "Track %d", i+1);
+		arr_snprintf(path, "CDDA %s %lX %d", drive->device_path, drive->disc.hash, i+1);
+		arr_snprintf(sort, "%02d", i+1);
 
 		if ((data = (cdda_track_t *)malloc(sizeof(cdda_track_t))) == NULL) {
 			fprintf(stderr, "update_track_data: malloc error\n");
@@ -725,14 +724,14 @@ insert_cdda_drive_node(char * device_path) {
 	}
 
 	if (drive->disc.n_tracks > 0) {
-		snprintf(str_title, MAXLEN-1, "%s [%s]",
-			 _("Unknown disc"), cdda_displayed_device_path(device_path));
+		arr_snprintf(str_title, "%s [%s]",
+			     _("Unknown disc"), cdda_displayed_device_path(device_path));
 	} else {
-		snprintf(str_title, MAXLEN-1, "%s [%s]",
-			 _("No disc"), cdda_displayed_device_path(device_path));
+		arr_snprintf(str_title, "%s [%s]",
+			     _("No disc"), cdda_displayed_device_path(device_path));
 	}
 
-	snprintf(str_sort, 15, "%d", cdda_get_n(device_path));
+	arr_snprintf(str_sort, "%d", cdda_get_n(device_path));
 
 	gtk_tree_model_get_iter_first(GTK_TREE_MODEL(music_store), &iter_cdda);
 
@@ -810,11 +809,11 @@ refresh_cdda_drive_node(char * device_path) {
 	}
 
 	if (drive->disc.n_tracks > 0) {
-		snprintf(str_title, MAXLEN-1, "%s [%s]", _("Unknown disc"),
-			 cdda_displayed_device_path(device_path));
+		arr_snprintf(str_title, "%s [%s]", _("Unknown disc"),
+			     cdda_displayed_device_path(device_path));
 	} else {
-		snprintf(str_title, MAXLEN-1, "%s [%s]", _("No disc"),
-			 cdda_displayed_device_path(device_path));
+		arr_snprintf(str_title, "%s [%s]", _("No disc"),
+			     cdda_displayed_device_path(device_path));
 	}
 
 	gtk_tree_store_set(music_store, &iter_drive, MS_COL_NAME, str_title, -1);
