@@ -15,11 +15,12 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: core.c 1310 2015-07-26 19:11:40Z tszilagyi $
+    $Id$
 */
 
 #include <config.h>
 
+#include <libgen.h>
 #include <stddef.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -119,6 +120,10 @@ GSList * saved_pconns_L = NULL;
 GSList * saved_pconns_R = NULL;
 #endif /* HAVE_JACK */
 
+#ifdef HAVE_SNDIO
+int sndio_reinit(thread_info_t * info, int verbose);
+#endif /* HAVE_SNDIO */
+
 const size_t sample_size = sizeof(float);
 
 gint playlist_state, browser_state;
@@ -347,10 +352,10 @@ disk_thread(void * arg) {
 				rb_read(rb_gui2disk, (void *)&cue, sizeof(cue_t));
 				
 #ifdef HAVE_CDDA
-				strcpy(filename_prev, filename);
+				arr_strlcpy(filename_prev, filename);
 #endif /* HAVE_CDDA */
 				if (cue.filename != NULL) {
-					strncpy(filename, cue.filename, MAXLEN-1);
+					arr_strlcpy(filename, cue.filename);
 					free(cue.filename);
 				} else {
 					filename[0] = '\0';
@@ -802,8 +807,15 @@ sndio_thread(void * arg) {
 
 		/* write data to audio device */
 		bytes_written = sio_write(sndio_hdl, sndio_short_buf, 2*n_avail * sizeof(short));
-		if (bytes_written != 2*n_avail * sizeof(short))
+		if (bytes_written != 2*n_avail * sizeof(short)) {
 			fprintf(stderr, "sndio_thread: Error writing to audio device\n");
+			if (sndio_reinit(info, 1) == 0) {
+				fprintf(stderr, "sndio_thread: audio device reinit successful\n");
+				sio_close(sndio_hdl);
+				sndio_hdl = info->sndio_hdl;
+				goto sndio_wake;
+			}
+		}
 	}
  sndio_finish:
 	return 0;
@@ -1235,7 +1247,7 @@ jack_info_shutdown(jack_status_t code, const char * reason, void * arg) {
  * -N : unable to start with given params
  */
 int
-sndio_init(thread_info_t * info, int verbose, gboolean realtime, int priority) {
+sndio_reinit(thread_info_t * info, int verbose) {
 
 	struct sio_hdl * sndio_hdl;
 	struct sio_par sndio_par;
@@ -1300,6 +1312,15 @@ sndio_init(thread_info_t * info, int verbose, gboolean realtime, int priority) {
 	}
 
 	info->sndio_hdl = sndio_hdl;
+	return 0;
+}
+
+int
+sndio_init(thread_info_t * info, int verbose, gboolean realtime, int priority) {
+	int ret;
+	if ((ret = sndio_reinit(info, verbose)) != 0) {
+		return ret;
+	}
 	AQUALUNG_THREAD_CREATE(info->sndio_thread_id, NULL, sndio_thread, info)
 	set_thread_priority(info->sndio_thread_id, "sndio output", realtime, priority);
 
@@ -1887,6 +1908,8 @@ load_default_cl(int * argc, char *** argv) {
         if (chdir(options.confdir) != 0) {
                 if (errno == ENOENT) {
                         fprintf(stderr, "Creating directory %s\n", options.confdir);
+                        /* Try creating .config before .config/aqualung */
+                        mkdir(dirname(options.confdir), S_IRUSR | S_IWUSR | S_IXUSR);
                         if (mkdir(options.confdir, S_IRUSR | S_IWUSR | S_IXUSR) < 0) {
 				perror("cannot create config directory: mkdir");
 				exit(1);
@@ -1902,7 +1925,7 @@ load_default_cl(int * argc, char *** argv) {
                 }
         }
 
-        sprintf(config_file, "%s/config.xml", options.confdir);
+        arr_snprintf(config_file, "%s/config.xml", options.confdir);
         if ((f = fopen(config_file, "rt")) == NULL) {
                 fprintf(stderr, "No config.xml -- creating empty one: %s\n", config_file);
                 fprintf(stderr, "Wired-in defaults will be used.\n");
@@ -1942,7 +1965,7 @@ load_default_cl(int * argc, char *** argv) {
                 if ((!xmlStrcmp(cur->name, (const xmlChar *)"default_param"))) {
                         key = xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
                         if (key != NULL)
-                                strncpy(default_param, (char *) key, MAXLEN-1);
+                                arr_strlcpy(default_param, (char *) key);
                         xmlFree(key);
                 }
                 cur = cur->next;
@@ -1950,7 +1973,7 @@ load_default_cl(int * argc, char *** argv) {
 
         xmlFreeDoc(doc);
 
-	snprintf(cl, MAXLEN-1, "aqualung %s", default_param);
+	arr_snprintf(cl, "aqualung %s", default_param);
 	while (cl[i] != '\0') {
 		++(*argc);
 		if ((*argv = realloc(*argv, *argc * sizeof(char *))) == NULL) {
@@ -2338,13 +2361,13 @@ setup_app_directories(void) {
         char * xdgconfdir;
 	if (!home) {
 		char * homedir = (char *)g_get_home_dir();
-		strcpy(options.home, homedir);
+		arr_strlcpy(options.home, homedir);
 		g_free(homedir);
 	} else {
-		strcpy(options.home, home);
+		arr_strlcpy(options.home, home);
 	}
 
-	snprintf(options.confdir, MAXLEN-1, "%s/.aqualung", options.home);
+	arr_snprintf(options.confdir, "%s/.aqualung", options.home);
         xdgconfdir = g_build_filename(g_get_user_config_dir(), "aqualung", NULL);
 	if (!g_file_test(xdgconfdir, G_FILE_TEST_IS_DIR) &&
 	    g_file_test(options.confdir, G_FILE_TEST_IS_DIR)) {
@@ -2357,20 +2380,20 @@ setup_app_directories(void) {
 			exit(1);
 		}
 	}
-	strncpy(options.confdir, xdgconfdir, MAXLEN-1);
+	arr_strlcpy(options.confdir, xdgconfdir);
 	g_free(xdgconfdir);
 
-	strcpy(options.audiodir, options.home);
-	strcpy(options.currdir, options.home);
-	strcpy(options.exportdir, options.home);
-	strcpy(options.plistdir, options.home);
-	strcpy(options.podcastdir, options.home);
-	strcpy(options.ripdir, options.home);
-	strcpy(options.storedir, options.home);
+	arr_strlcpy(options.audiodir, options.home);
+	arr_strlcpy(options.currdir, options.home);
+	arr_strlcpy(options.exportdir, options.home);
+	arr_strlcpy(options.plistdir, options.home);
+	arr_strlcpy(options.podcastdir, options.home);
+	arr_strlcpy(options.ripdir, options.home);
+	arr_strlcpy(options.storedir, options.home);
 
 	if (getcwd(options.cwd, MAXLEN) == NULL) {
 		fprintf(stderr, "setup_app_directories(): warning: getcwd() returned NULL, using . as cwd\n");
-		strcpy(options.cwd, ".");
+		arr_strlcpy(options.cwd, ".");
 	}
 }
 
@@ -2787,7 +2810,7 @@ main(int argc, char ** argv) {
 			no_session = 0;
 		buf[0] = RCMD_VOLADJ;
 		buf[1] = '\0';
-		strncat(buf, voladj_arg, MAXLEN-2);
+		arr_strlcat(buf, voladj_arg);
 		send_message_to_session(no_session, buf, strlen(buf));
 		exit(1);
 	}
@@ -2799,7 +2822,7 @@ main(int argc, char ** argv) {
 			no_session = 0;
 		buf[0] = RCMD_CUSTOM;
 		buf[1] = '\0';
-		strncat(buf, custom_arg, MAXLEN-2);
+		arr_strlcat(buf, custom_arg);
 		send_message_to_session(no_session, buf, strlen(buf));
 		exit(0);
 	}
@@ -2807,7 +2830,7 @@ main(int argc, char ** argv) {
 	if (no_session != -1) {
 		char sockname[MAXLEN];
 
-		sprintf(sockname, "/tmp/aqualung_%s.%d", g_get_user_name(), no_session);
+		arr_snprintf(sockname, "/tmp/aqualung_%s.%d", g_get_user_name(), no_session);
 		if (!g_file_test(sockname, G_FILE_TEST_EXISTS)) {
 			no_session = -1;
 		}
@@ -2822,11 +2845,11 @@ main(int argc, char ** argv) {
 
 			for (i = optind; argv[i] != NULL; i++) {				
 
-				normalize_filename(argv[i], fullname);
+				normalize_filename(argv[i], fullname, CHAR_ARRAY_SIZE(fullname));
 
 				buffer[0] = RCMD_ADD_FILE;
 				buffer[1] = '\0';
-				strncat(buffer, fullname, MAXLEN-2);
+				arr_strlcat(buffer, fullname);
 				send_message_to_session(no_session, buffer, strlen(buffer));
 			}
 
@@ -2839,7 +2862,7 @@ main(int argc, char ** argv) {
 				buffer[4] = '\0';
 
 				if (tab_name != NULL) {
-					strncat(buffer + 4, tab_name, MAXLEN-5);
+					g_strlcat(buffer + 4, tab_name, CHAR_ARRAY_SIZE(buffer) - 4);
 				}
 
 				send_message_to_session(no_session, buffer, 4 + strlen(buffer + 4));
