@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: dec_flac.c 1245 2012-02-04 10:33:30Z assworth $
+    $Id$
 */
 
 #include <config.h>
@@ -495,7 +495,7 @@ flac_decoder_open(decoder_t * dec, char * filename) {
 				* fdec->fileinfo.channels;
 
 			fdec->file_lib = FLAC_LIB;
-			strcpy(dec->format_str, "FLAC");
+			arr_strlcpy(dec->format_str, "FLAC");
 
 			flac_send_metadata(dec);
 			return DECODER_OPEN_SUCCESS;
