@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: export.c 1292 2014-05-02 12:29:01Z tszilagyi $
+    $Id$
 */
 
 #include <config.h>
@@ -299,7 +299,7 @@ export_finish(gpointer user_data) {
 }
 
 int
-export_item_set_path(export_t * export, export_item_t * item, char * path, char * ext, int index) {
+export_item_set_path(export_t * export, export_item_t * item, char * path, size_t path_len, char * ext, int index) {
 
 	char track[MAXLEN];
 	char buf[3*MAXLEN];
@@ -309,11 +309,11 @@ export_item_set_path(export_t * export, export_item_t * item, char * path, char
 	track[0] = '\0';
 	buf[0] = '\0';
 
-	strcat(buf, export->outdir);
+	arr_strlcat(buf, export->outdir);
 
 	if (export->dir_for_artist) {
-		strcat(buf, "/");
-		strcat(buf, export_map_put(&export->artist_map, item->artist, export->dir_len_limit));
+		arr_strlcat(buf, "/");
+		arr_strlcat(buf, export_map_put(&export->artist_map, item->artist, export->dir_len_limit));
 		if (!is_dir(buf) && mkdir(buf, S_IRUSR | S_IWUSR | S_IXUSR) < 0) {
 			fprintf(stderr, "mkdir: %s: %s\n", buf, strerror(errno));
 			return -1;
@@ -321,21 +321,22 @@ export_item_set_path(export_t * export, export_item_t * item, char * path, char
 	}
 
 	if (export->dir_for_album) {
-		strcat(buf, "/");
-		strcat(buf, export_map_put(&export->record_map, item->album, export->dir_len_limit));
+		arr_strlcat(buf, "/");
+		arr_strlcat(buf, export_map_put(&export->record_map, item->album, export->dir_len_limit));
 		if (!is_dir(buf) && mkdir(buf, S_IRUSR | S_IWUSR | S_IXUSR) < 0) {
 			fprintf(stderr, "mkdir: %s: %s\n", buf, strerror(errno));
 			return -1;
 		}
 	}
 
-	snprintf(str_no, 15, "%02d", item->no);
-	snprintf(str_index, 15, "%04d", index);
+	arr_snprintf(str_no, "%02d", item->no);
+	arr_snprintf(str_index, "%04d", index);
 
-	make_string_va(track, export->template, 'o', item->original, 'a', item->artist,
-		       'r', item->album, 't', item->title, 'n', str_no, 'x', ext, 'i', str_index, 0);
+	make_string_va(track, CHAR_ARRAY_SIZE(track), export->template,
+		       'o', item->original, 'a', item->artist, 'r', item->album,
+		       't', item->title, 'n', str_no, 'x', ext, 'i', str_index, 0);
 
-	snprintf(path, MAXLEN-1, "%s/%s", buf, track);
+	snprintf(path, path_len, "%s/%s", buf, track);
 	return 0;
 }
 
@@ -349,7 +350,7 @@ update_progbar_ratio(gpointer user_data) {
 		char tmp[16];
 
 		AQUALUNG_MUTEX_LOCK(export->mutex);
-		snprintf(tmp, 15, "%d%%", (int)(export->ratio * 100));
+		arr_snprintf(tmp, "%d%%", (int)(export->ratio * 100));
 		gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(export->progbar), export->ratio);
 		AQUALUNG_MUTEX_UNLOCK(export->mutex);
 		gtk_progress_bar_set_text(GTK_PROGRESS_BAR(export->progbar), tmp);
@@ -404,7 +405,7 @@ void
 set_prog_src_file_entry(export_t * export, char * file) {
 
 	AQUALUNG_MUTEX_LOCK(export->mutex);
-	strncpy(export->file1, file, MAXLEN-1);
+	arr_strlcpy(export->file1, file);
         AQUALUNG_MUTEX_UNLOCK(export->mutex);
 
 	aqualung_idle_add(set_prog_src_file_entry_idle, export);
@@ -414,7 +415,7 @@ void
 set_prog_trg_file_entry(export_t * export, char * file) {
 
 	AQUALUNG_MUTEX_LOCK(export->mutex);
-	strncpy(export->file2, file, MAXLEN-1);
+	arr_strlcpy(export->file2, file);
         AQUALUNG_MUTEX_UNLOCK(export->mutex);
 
 	aqualung_idle_add(set_prog_trg_file_entry_idle, export);
@@ -455,7 +456,7 @@ export_meta_amend_frame(metadata_t * meta, int tag, int type, export_item_t * it
 	case META_FIELD_DATE:
 		{
 			char str_year[6];
-			snprintf(str_year, 5, "%d", item->year);
+			arr_snprintf(str_year, "%d", item->year);
 			frame->field_val = strdup(str_year);
 		}
 		break;
@@ -583,7 +584,7 @@ export_item(export_t * export, export_item_t * item, int index) {
 		}
 	}
 
-	if (export_item_set_path(export, item, filename, ext, index) < 0) {
+	if (export_item_set_path(export, item, filename, CHAR_ARRAY_SIZE(filename), ext, index) < 0) {
 		file_decoder_close(fdec);
 		file_decoder_delete(fdec);
 		return;
@@ -640,7 +641,7 @@ export_item(export_t * export, export_item_t * item, int index) {
 	}
 
 
-	strncpy(mode.filename, filename, MAXLEN-1);
+	arr_strlcpy(mode.filename, filename);
 	mode.file_lib = export->format;
 	mode.sample_rate = fdec->fileinfo.sample_rate;
 	mode.channels = fdec->fileinfo.channels;
@@ -727,7 +728,7 @@ export_browse_cb(GtkButton * button, gpointer data) {
 				GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
 				FILE_CHOOSER_FILTER_NONE,
 				(GtkWidget *)data,
-				options.exportdir);
+				options.exportdir, CHAR_ARRAY_SIZE(options.exportdir));
 }
 
 GtkWidget *
@@ -855,11 +856,11 @@ export_bitrate_changed(GtkRange * range, gpointer data) {
 		switch (i) {
 		case 0:
 		case 8:
-			snprintf(str, 255, "%d (%s)", i, (i == 0) ? _("fast") : _("best"));
+			arr_snprintf(str, "%d (%s)", i, (i == 0) ? _("fast") : _("best"));
 			gtk_label_set_text(GTK_LABEL(export->bitrate_value_label), str);
 			break;
 		default:
-			snprintf(str, 255, "%d", i);
+			arr_snprintf(str, "%d", i);
 			gtk_label_set_text(GTK_LABEL(export->bitrate_value_label), str);
 			break;
 		}
@@ -867,7 +868,7 @@ export_bitrate_changed(GtkRange * range, gpointer data) {
 	if (strcmp(text, "Ogg Vorbis") == 0) {
 		int i = (int)val;
 		char str[256];
-		snprintf(str, 255, "%d", i);
+		arr_snprintf(str, "%d", i);
 		gtk_label_set_text(GTK_LABEL(export->bitrate_value_label), str);
 	}
 	if (strcmp(text, "MP3") == 0) {
@@ -876,7 +877,7 @@ export_bitrate_changed(GtkRange * range, gpointer data) {
 #ifdef HAVE_LAME
 		i = lame_encoder_validate_bitrate(i, 0);
 #endif /* HAVE_LAME */
-		snprintf(str, 255, "%d", i);
+		arr_snprintf(str, "%d", i);
 		gtk_label_set_text(GTK_LABEL(export->bitrate_value_label), str);
 	}
 	g_free(text);
@@ -1019,7 +1020,7 @@ export_dialog_response(GtkDialog * dialog, gint response_id, gpointer ex) {
 		return FALSE;
 	}
 	
-	normalize_filename(poutdir, export->outdir);
+	normalize_filename(poutdir, export->outdir, CHAR_ARRAY_SIZE(export->outdir));
 	g_free(poutdir);
 	
 	if (strlen(gtk_entry_get_text(GTK_ENTRY(export->templ_entry))) == 0) {
@@ -1029,9 +1030,9 @@ export_dialog_response(GtkDialog * dialog, gint response_id, gpointer ex) {
 		int ret;
 		char buf[MAXLEN];
 		char * format = (char *)gtk_entry_get_text(GTK_ENTRY(export->templ_entry));
-		if ((ret = make_string_va(buf, format,
+		if ((ret = make_string_va(buf, CHAR_ARRAY_SIZE(buf), format,
 					  'o', "o", 'a', "a", 'r', "r", 't', "t", 'n', "n", 'x', "x", 'i', "i", 0)) != 0) {
-			make_string_strerror(ret, buf);
+			make_string_strerror(ret, buf, CHAR_ARRAY_SIZE(buf));
 			message_dialog(_("Error in format string"),
 				       export->dialog,
 				       GTK_MESSAGE_ERROR,
@@ -1054,9 +1055,9 @@ export_dialog_response(GtkDialog * dialog, gint response_id, gpointer ex) {
 		return FALSE;
 	}
 	
-	strncpy(options.exportdir, export->outdir, MAXLEN-1);
-	set_option_from_entry(export->templ_entry, export->template, MAXLEN);
-	set_option_from_entry(export->templ_entry, options.export_template, MAXLEN);
+	arr_strlcpy(options.exportdir, export->outdir);
+	set_option_from_entry(export->templ_entry, export->template, CHAR_ARRAY_SIZE(export->template));
+	set_option_from_entry(export->templ_entry, options.export_template, CHAR_ARRAY_SIZE(options.export_template));
 	options.export_file_format = export->format = export_get_format_from_combo(export->format_combo);
 	options.export_bitrate = export->bitrate = gtk_range_get_value(GTK_RANGE(export->bitrate_scale));
 	set_option_from_toggle(export->check_dir_artist, &options.export_subdir_artist);
@@ -1075,7 +1076,7 @@ export_dialog_response(GtkDialog * dialog, gint response_id, gpointer ex) {
 	options.export_excl_enabled = export->excl_enabled;
 	
 	if (export->excl_enabled) {
-		set_option_from_entry(export->excl_entry, options.export_excl_pattern, MAXLEN);
+		set_option_from_entry(export->excl_entry, options.export_excl_pattern, CHAR_ARRAY_SIZE(options.export_excl_pattern));
 		export->excl_patternv =
 			g_strsplit(gtk_entry_get_text(GTK_ENTRY(export->excl_entry)), ",", 0);
 	}
