@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: file_info.c 1298 2014-05-19 12:53:11Z tszilagyi $
+    $Id$
 */
 
 #include <config.h>
@@ -416,10 +416,10 @@ fi_set_frame_from_source(fi_t * fi, meta_frame_t * frame) {
 		const char * str = gtk_entry_get_text(GTK_ENTRY(frame->source));
 		if (sscanf(str, parsefmt, &val) < 1) {
 			char msg[MAXLEN];
-			snprintf(msg, MAXLEN-1,
-				 _("Conversion error in field %s:\n"
-				   "'%s' does not conform to format '%s'!"),
-				 frame->field_name, str, "%s");
+			arr_snprintf(msg,
+				     _("Conversion error in field %s:\n"
+				       "'%s' does not conform to format '%s'!"),
+				     frame->field_name, str, "%s");
 			message_dialog(_("Error"),
 				       fi->info_window, GTK_MESSAGE_ERROR,
 				       GTK_BUTTONS_OK, NULL, msg, parsefmt_esc);
@@ -432,10 +432,10 @@ fi_set_frame_from_source(fi_t * fi, meta_frame_t * frame) {
 		const char * str = gtk_entry_get_text(GTK_ENTRY(frame->source));
 		if (sscanf(str, parsefmt, &val) < 1) {
 			char msg[MAXLEN];
-			snprintf(msg, MAXLEN-1,
-				 _("Conversion error in field %s:\n"
-				   "'%s' does not conform to format '%s'!"),
-				 frame->field_name, str, "%s");
+			arr_snprintf(msg,
+				     _("Conversion error in field %s:\n"
+				       "'%s' does not conform to format '%s'!"),
+				     frame->field_name, str, "%s");
 			message_dialog(_("Error"),
 				       fi->info_window, GTK_MESSAGE_ERROR,
 				       GTK_BUTTONS_OK, NULL, msg, parsefmt_esc);
@@ -552,10 +552,10 @@ import_button_pressed(GtkWidget * widget, gpointer gptr_data) {
 		gtk_tree_model_get(GTK_TREE_MODEL(music_store), &record_iter, MS_COL_DATA, &record_data, -1);
 		if (sscanf(frame->field_val, "%d", &record_data->year) < 1) {
 			char msg[MAXLEN];
-			snprintf(msg, MAXLEN-1,
-				 _("Error converting field %s to Year:\n"
-				   "'%s' is not an integer number!"),
-				 frame->field_name, frame->field_val);
+			arr_snprintf(msg,
+				     _("Error converting field %s to Year:\n"
+				       "'%s' is not an integer number!"),
+				     frame->field_name, frame->field_val);
 			message_dialog(_("Error"),
 				       fi->info_window, GTK_MESSAGE_ERROR,
 				       GTK_BUTTONS_OK, NULL, msg);
@@ -565,7 +565,7 @@ import_button_pressed(GtkWidget * widget, gpointer gptr_data) {
 		}
 		break;
 	case IMPORT_DEST_NUMBER:
-		snprintf(tmp, MAXLEN-1, "%02d", frame->int_val);
+		arr_snprintf(tmp, "%02d", frame->int_val);
 		gtk_tree_store_set(music_store, &iter_track, MS_COL_SORT, tmp, -1);
 		music_store_mark_changed(&iter_track);
 		break;
@@ -573,12 +573,12 @@ import_button_pressed(GtkWidget * widget, gpointer gptr_data) {
 		gtk_tree_model_get(model, &iter_track, MS_COL_DATA, &track_data, -1);
 		tmp[0] = '\0';
 		if (track_data->comment != NULL) {
-			strncat(tmp, track_data->comment, MAXLEN-1);
+			arr_strlcat(tmp, track_data->comment);
 		}
 		if ((tmp[strlen(tmp)-1] != '\n') && (tmp[0] != '\0')) {
-			strncat(tmp, "\n", MAXLEN-1);
+			arr_strlcat(tmp, "\n");
 		}
-		strncat(tmp, frame->field_val, MAXLEN-1);
+		arr_strlcat(tmp, frame->field_val);
 		free_strdup(&track_data->comment, tmp);
 		music_store_mark_changed(&iter_track);
 		break;
@@ -641,7 +641,7 @@ save_pic_button_pressed(GtkWidget * widget, gpointer data) {
 	char * dirname;
 
 	dirname = g_path_get_dirname(options.currdir);
-	snprintf(filename, MAXLEN-1, "%s/%s", dirname, save_pic->savefile);
+	arr_snprintf(filename, "%s/%s", dirname, save_pic->savefile);
 	g_free(dirname);
 
 	lfiles = file_chooser(_("Please specify the file to save the image to."),
@@ -649,7 +649,7 @@ save_pic_button_pressed(GtkWidget * widget, gpointer data) {
 			      GTK_FILE_CHOOSER_ACTION_SAVE,
 			      FILE_CHOOSER_FILTER_NONE,
 			      FALSE,
-			      filename);
+			      filename, CHAR_ARRAY_SIZE(filename));
 
 	if (lfiles != NULL) {
 
@@ -667,7 +667,7 @@ save_pic_button_pressed(GtkWidget * widget, gpointer data) {
 		}
 		fclose(f);
 
-		strncpy(options.currdir, filename, MAXLEN-1);
+		arr_strlcpy(options.currdir, filename);
 	}
 }
 
@@ -680,21 +680,21 @@ save_pic_update(save_pic_t * save_pic, fi_t * fi, meta_frame_t * frame) {
 	char savefilename[256];
 
 	mtype[0] = '\0';
-	strcpy(savefilename, "picture.");
+	arr_strlcpy(savefilename, "picture.");
 	r = sscanf(frame->field_name, "image/%s", mtype);
 	if (r == 0) {
-		strncpy(mtype, frame->field_name, 19);
+		arr_strlcpy(mtype, frame->field_name);
 	}
 	for (i = 0; mtype[i] != '\0'; i++) {
 		mtype[i] = tolower(mtype[i]);
 	}
 	if (mtype[0] == '\0') {
-		strcpy(mtype, "dat");
+		arr_strlcpy(mtype, "dat");
 	}
-	strncat(savefilename, mtype, 255);
+	arr_strlcat(savefilename, mtype);
 
 	save_pic->fi = fi;
-	strncpy(save_pic->savefile, savefilename, MAXLEN-1);
+	arr_strlcpy(save_pic->savefile, savefilename);
 	save_pic->image_size = frame->length;
 	save_pic->image_data = frame->data;
 
@@ -779,7 +779,7 @@ change_pic_button_pressed(GtkWidget * widget, gpointer data) {
 			      GTK_FILE_CHOOSER_ACTION_OPEN,
 			      FILE_CHOOSER_FILTER_NONE,
 			      FALSE,
-			      options.currdir);
+			      options.currdir, CHAR_ARRAY_SIZE(options.currdir));
 
 	if (lfiles != NULL) {
 		g_slist_free(lfiles);
@@ -790,7 +790,7 @@ change_pic_button_pressed(GtkWidget * widget, gpointer data) {
 	pformat = gdk_pixbuf_get_file_info(options.currdir, NULL, NULL);
 	if (pformat == NULL) {
 		char msg[MAXLEN];
-		snprintf(msg, MAXLEN-1, _("Could not load image from:\n%s"), options.currdir);
+		arr_snprintf(msg, _("Could not load image from:\n%s"), options.currdir);
 		message_dialog(_("Error"), fi->info_window, GTK_MESSAGE_ERROR,
 			       GTK_BUTTONS_OK, NULL, msg);
 		return;
@@ -823,7 +823,7 @@ change_pic_button_pressed(GtkWidget * widget, gpointer data) {
 	source->image = make_image_from_binary(frame);
 	gtk_widget_show(source->image);
 	gtk_container_add(GTK_CONTAINER(vbox), source->image);
-	snprintf(str, MAXLEN-1, _("MIME type: %s"), frame->field_name);
+	arr_snprintf(str, _("MIME type: %s"), frame->field_name);
 	gtk_label_set_text(GTK_LABEL(source->mime_label), str);
 	/* update callback data for 'Save picture' */
 	save_pic_update(save_pic, fi, frame);
@@ -870,7 +870,7 @@ fi_procframe_label_apic(fi_t * fi, meta_frame_t * frame) {
 	source = ((apic_source_t *)(frame->source));
 
 	meta_get_fieldname(META_FIELD_APIC, &pic_caption);
-	snprintf(str, MAXLEN-1, "%s:", pic_caption);
+	arr_snprintf(str, "%s:", pic_caption);
 
 	label_frame = gtk_frame_new(pic_caption);
 	gtk_container_add(GTK_CONTAINER(label_frame), vbox);
@@ -879,7 +879,7 @@ fi_procframe_label_apic(fi_t * fi, meta_frame_t * frame) {
 
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 3);
-	snprintf(str, MAXLEN-1, _("MIME type: %s"), frame->field_name);
+	arr_snprintf(str, _("MIME type: %s"), frame->field_name);
 	source->mime_label = gtk_label_new(str);
 	gtk_box_pack_start(GTK_BOX(hbox), source->mime_label, FALSE, FALSE, 0);
 
@@ -907,8 +907,8 @@ fi_procframe_label_apic(fi_t * fi, meta_frame_t * frame) {
 	} else {
 		hbox = gtk_hbox_new(FALSE, 0);
 		gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 3);
-		snprintf(str, MAXLEN-1, "%s",
-			 meta_id3v2_apic_type_to_string(frame->int_val));
+		arr_snprintf(str, "%s",
+			     meta_id3v2_apic_type_to_string(frame->int_val));
 		label = gtk_label_new(str);
 		gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	}
@@ -967,7 +967,7 @@ fi_procframe_label(fi_t * fi, meta_frame_t * frame) {
 		char str[MAXLEN];
 		GtkWidget * hbox = gtk_hbox_new(FALSE, 0);
 		GtkWidget * label;
-		snprintf(str, MAXLEN-1, "%s:", frame->field_name);
+		arr_snprintf(str, "%s:", frame->field_name);
 		label = gtk_label_new(str);
 		gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 		return hbox;
@@ -1068,13 +1068,13 @@ fi_procframe_entry(fi_t * fi, meta_frame_t * frame) {
 		char str[MAXLEN];
 		char * format = meta_get_field_renderfmt(frame->type);
 		widget = entry = gtk_entry_new();
-		snprintf(str, MAXLEN-1, format, frame->int_val);
+		arr_snprintf(str, format, frame->int_val);
 		gtk_entry_set_text(GTK_ENTRY(entry), str);
 	} else if (META_FIELD_FLOAT(frame->type)) {
 		char str[MAXLEN];
 		char * format = meta_get_field_renderfmt(frame->type);
 		widget = entry = gtk_entry_new();
-		snprintf(str, MAXLEN-1, format, frame->float_val);
+		arr_snprintf(str, format, frame->float_val);
 		gtk_entry_set_text(GTK_ENTRY(entry), str);
 	} else {
 		if (meta->writable && (frame->type == META_FIELD_GENRE)) {
@@ -1102,7 +1102,7 @@ fi_procframe_entry(fi_t * fi, meta_frame_t * frame) {
 
 
 import_data_t *
-make_import_data_from_frame(fi_t * fi, meta_frame_t * frame, char * label) {
+make_import_data_from_frame(fi_t * fi, meta_frame_t * frame, char * label, size_t label_size) {
 
 	import_data_t * data = import_data_new();
 	trashlist_add(fi->trash, data);
@@ -1112,33 +1112,33 @@ make_import_data_from_frame(fi_t * fi, meta_frame_t * frame, char * label) {
 	switch (frame->type) {
 	case META_FIELD_TITLE:
 		data->dest_type = IMPORT_DEST_TITLE;
-		strcpy(label, _("Import as Title"));
+		g_strlcpy(label, _("Import as Title"), label_size);
 		break;
 	case META_FIELD_ARTIST:
 		data->dest_type = IMPORT_DEST_ARTIST;
-		strcpy(label, _("Import as Artist"));
+		g_strlcpy(label, _("Import as Artist"), label_size);
 		break;
 	case META_FIELD_ALBUM:
 		data->dest_type = IMPORT_DEST_RECORD;
-		strcpy(label, _("Import as Record"));
+		g_strlcpy(label, _("Import as Record"), label_size);
 		break;
 	case META_FIELD_DATE:
 		data->dest_type = IMPORT_DEST_YEAR;
-		strcpy(label, _("Import as Year"));
+		g_strlcpy(label, _("Import as Year"), label_size);
 		break;
 	case META_FIELD_TRACKNO:
 		data->dest_type = IMPORT_DEST_NUMBER;
-		strcpy(label, _("Import as Track No."));
+		g_strlcpy(label, _("Import as Track No."), label_size);
 		break;
 	case META_FIELD_RG_TRACK_GAIN:
 	case META_FIELD_RG_ALBUM_GAIN:
 	case META_FIELD_RVA2:
 		data->dest_type = IMPORT_DEST_RVA;
-		strcpy(label, _("Import as RVA"));
+		g_strlcpy(label, _("Import as RVA"), label_size);
 		break;
 	default:
 		data->dest_type = IMPORT_DEST_COMMENT;
-		strcpy(label, _("Add to Comments"));
+		g_strlcpy(label, _("Add to Comments"), label_size);
 		break;
 	}
 
@@ -1153,7 +1153,7 @@ fi_procframe_importbtn(fi_t * fi, meta_frame_t * frame) {
 	GtkWidget * button = gtk_button_new();
 	g_signal_connect(G_OBJECT(button), "clicked",
 			 G_CALLBACK(import_button_pressed),
-			 (gpointer)make_import_data_from_frame(fi, frame, label));
+			 (gpointer)make_import_data_from_frame(fi, frame, label, CHAR_ARRAY_SIZE(label)));
 	gtk_button_set_label(GTK_BUTTON(button), label);
 	return button;
 }
@@ -1820,33 +1820,33 @@ fi_set_common_entries(fi_t * fi) {
 	gtk_entry_set_text(GTK_ENTRY(fi->entry_format), fi->fileinfo.format_str);
 
 	if (fi->fileinfo.total_samples == 0) {
-		strcpy(str, "N/A");
+		arr_strlcpy(str, "N/A");
 	} else {
-		sample2time(fi->fileinfo.sample_rate, fi->fileinfo.total_samples, str, 0);
+		sample2time(fi->fileinfo.sample_rate, fi->fileinfo.total_samples, str, CHAR_ARRAY_SIZE(str), 0);
 	}
 	gtk_entry_set_text(GTK_ENTRY(fi->entry_length), str);
 
-	sprintf(str, _("%ld Hz"), fi->fileinfo.sample_rate);
+	arr_snprintf(str, _("%ld Hz"), fi->fileinfo.sample_rate);
 	gtk_entry_set_text(GTK_ENTRY(fi->entry_sr), str);
 
 	if (fi->fileinfo.is_mono) {
-		strcpy(str, _("MONO"));
+		arr_strlcpy(str, _("MONO"));
 	} else {
-		strcpy(str, _("STEREO"));
+		arr_strlcpy(str, _("STEREO"));
 	}
 	gtk_entry_set_text(GTK_ENTRY(fi->entry_ch), str);
 
 	if (fi->fileinfo.bps == 0) {
-		strcpy(str, "N/A kbit/s");
+		arr_strlcpy(str, "N/A kbit/s");
 	} else {
-		format_bps_label(fi->fileinfo.bps, fi->fileinfo.format_flags, str);
+		format_bps_label(fi->fileinfo.bps, fi->fileinfo.format_flags, str, CHAR_ARRAY_SIZE(str));
 	}
 	gtk_entry_set_text(GTK_ENTRY(fi->entry_bw), str);
 
 	if (fi->fileinfo.total_samples == 0) {
-		strcpy(str, "N/A");
+		arr_strlcpy(str, "N/A");
 	} else {
-		sprintf(str, "%lld", fi->fileinfo.total_samples);
+		arr_snprintf(str, "%lld", fi->fileinfo.total_samples);
 	}
 	gtk_entry_set_text(GTK_ENTRY(fi->entry_nsamples), str);
 
@@ -1856,11 +1856,11 @@ fi_set_common_entries(fi_t * fi) {
 		int mode = WavpackGetMode(pd->wpc);
 
 		if ((mode & MODE_LOSSLESS) && (mode & MODE_WVC)) {
-			strncpy(str, "Hybrid Lossless", MAXLEN-1);
+			arr_strlcpy(str, "Hybrid Lossless");
 		} else if (mode & MODE_LOSSLESS) {
-			strncpy(str, "Lossless", MAXLEN-1);
+			arr_strlcpy(str, "Lossless");
 		} else {
-			strncpy(str, "Hybrid Lossy", MAXLEN-1);
+			arr_strlcpy(str, "Hybrid Lossy");
 		}
 		cut_trailing_whitespace(str);
 		gtk_entry_set_text(GTK_ENTRY(fi->entry_mode), str);
@@ -2141,7 +2141,7 @@ show_list(fi_t * fi, gint type) {
                                 ModPlug_SampleName(md_pd->mpf, i, temp);
                         }
 
-                        sprintf(number, "%2d", i);
+                        arr_snprintf(number, "%2d", i);
                         gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(fi->smp_instr_list_store), &iter, NULL, i);
                         gtk_list_store_append(fi->smp_instr_list_store, &iter);
                         gtk_list_store_set(fi->smp_instr_list_store, &iter, 0, number, 1, temp, -1);
@@ -2205,7 +2205,6 @@ module_info_fill_page(fi_t * fi, meta_frame_t * frame, GtkWidget * vbox) {
 	gint i, n;
 	gchar temp[MAXLEN];
 	GtkWidget *table;
-	GtkWidget *label;
 	GtkWidget *mod_type_label;
 	GtkWidget *mod_channels_label;
 	GtkWidget *mod_patterns_label;
@@ -2244,7 +2243,7 @@ module_info_fill_page(fi_t * fi, meta_frame_t * frame, GtkWidget * vbox) {
 		module_info_add_row(_("Samples:"), &mod_samples_label, table, 3);
 		module_info_add_row(_("Instruments:"), &mod_instruments_label, table, 4);
 
-                sprintf(temp, "%d", mdi->instruments);
+                arr_snprintf(temp, "%d", mdi->instruments);
                 gtk_label_set_text (GTK_LABEL(mod_instruments_label), temp);
 
                 table = gtk_table_new (2, 1, FALSE);
@@ -2290,11 +2289,11 @@ module_info_fill_page(fi_t * fi, meta_frame_t * frame, GtkWidget * vbox) {
         }
 
         gtk_label_set_text (GTK_LABEL(mod_type_label), a_type[i]);
-        sprintf(temp, "%d", mdi->channels);
+        arr_snprintf(temp, "%d", mdi->channels);
         gtk_label_set_text (GTK_LABEL(mod_channels_label), temp);
-        sprintf(temp, "%d", mdi->patterns);
+        arr_snprintf(temp, "%d", mdi->patterns);
         gtk_label_set_text (GTK_LABEL(mod_patterns_label), temp);
-        sprintf(temp, "%d", mdi->samples);
+        arr_snprintf(temp, "%d", mdi->samples);
         gtk_label_set_text (GTK_LABEL(mod_samples_label), temp);
 
         vseparator = gtk_vseparator_new ();
