@@ -16,7 +16,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: ifp_device.c 1292 2014-05-02 12:29:01Z tszilagyi $
+    $Id$
 */
 
 #include <config.h>
@@ -117,7 +117,7 @@ update_progress (void *context, struct ifp_transfer_status *status) {
         gchar temp[MAXLEN];
 
         gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(progressbar_cf), (float)status->file_bytes/status->file_total);
-        sprintf(temp, _("%.1f MB / %.1f MB"), (float)status->file_bytes/(1024*1024), (float)status->file_total/(1024*1024));
+        arr_snprintf(temp, _("%.1f MB / %.1f MB"), (float)status->file_bytes/(1024*1024), (float)status->file_total/(1024*1024));
         gtk_progress_bar_set_text (GTK_PROGRESS_BAR (progressbar_cf), temp);
 
         if (abort_pressed) {
@@ -148,18 +148,18 @@ upload_songs_cb_foreach(playlist_t * pl, GtkTreeIter * iter, void * data) {
 
 	file = g_path_get_basename(pldata->file);
 
-        strncpy(dest_file, remote_path, MAXLEN-1);
+        arr_strlcpy(dest_file, remote_path);
         if (strlen(remote_path) != 1) {
-                strncat(dest_file, "\\", MAXLEN-1);
+                arr_strlcat(dest_file, "\\");
         }
-        strncat(dest_file, file, MAXLEN-1);
+        arr_strlcat(dest_file, file);
 
         gtk_entry_set_text(GTK_ENTRY(aifp_file_entry), file);
         gtk_editable_set_position(GTK_EDITABLE(aifp_file_entry), -1);
 
         gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(progressbar_op),
                                       (float)(*n + 1) / number_of_songs);
-        sprintf(temp, _("%d / %d files"), *n + 1, number_of_songs);
+        arr_snprintf(temp, _("%d / %d files"), *n + 1, number_of_songs);
         gtk_progress_bar_set_text(GTK_PROGRESS_BAR (progressbar_op), temp);
 
         ifp_upload_file(&ifpdev, pldata->file, dest_file, update_progress, NULL);
@@ -188,15 +188,15 @@ download_songs_cb_foreach (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *
         gtk_tree_model_get (model, iter, COLUMN_NAME, &file, -1);
 
         if (strncmp(file, PARENTDIR, 2)) {
-                strncpy(remote_item, remote_path, MAXLEN-1);
+                arr_strlcpy(remote_item, remote_path);
                 if (strlen(remote_path) != 1) {
-                        strncat(remote_item, "\\", MAXLEN-1);
+                        arr_strlcat(remote_item, "\\");
                 }
-                strncat(remote_item, file, MAXLEN-1);
+                arr_strlcat(remote_item, file);
 
-                strncpy(dest_file, dest_dir, MAXLEN-1);
-                strncat(dest_file, "/", MAXLEN-1);
-                strncat(dest_file, file, MAXLEN-1);
+                arr_strlcpy(dest_file, dest_dir);
+                arr_strlcat(dest_file, "/");
+                arr_strlcat(dest_file, file);
 
                 gtk_entry_set_text(GTK_ENTRY(aifp_file_entry), file);
                 gtk_editable_set_position(GTK_EDITABLE(aifp_file_entry), -1);
@@ -205,11 +205,11 @@ download_songs_cb_foreach (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *
                                               (float)(*n + 1) / number_of_songs);
 
                 if (ifp_is_file (&ifpdev, remote_item) == TRUE) {
-                        sprintf(temp, _("%d / %d files"), *n + 1, number_of_songs);
+                        arr_snprintf(temp, _("%d / %d files"), *n + 1, number_of_songs);
                         gtk_progress_bar_set_text(GTK_PROGRESS_BAR (progressbar_op), temp);
                         ifp_download_file (&ifpdev, remote_item, dest_file, update_progress, NULL);
                 } else {
-                        sprintf(temp, _("%d / %d directories"), *n + 1, number_of_songs);
+                        arr_snprintf(temp, _("%d / %d directories"), *n + 1, number_of_songs);
                         gtk_progress_bar_set_text(GTK_PROGRESS_BAR (progressbar_op), temp);
                         ifp_download_dir (&ifpdev, remote_item, dest_file, update_progress, NULL);
                 }
@@ -344,11 +344,11 @@ aifp_create_directory_cb (GtkButton *button, gpointer user_data) {
 
         if (response == GTK_RESPONSE_OK) {
 
-                strncpy(temp, remote_path, MAXLEN-1);
+                arr_strlcpy(temp, remote_path);
                 if (strlen(remote_path) != 1) {
-                        strncat(temp, "\\", MAXLEN-1);
+                        arr_strlcat(temp, "\\");
                 }
-                strncat(temp, gtk_entry_get_text(GTK_ENTRY(name_entry)), MAXLEN-1);
+                arr_strlcat(temp, gtk_entry_get_text(GTK_ENTRY(name_entry)));
 
                 if (strlen(temp)) {
 
@@ -403,18 +403,18 @@ aifp_rename_item_cb (GtkButton *button, gpointer user_data) {
 
                         text = gtk_entry_get_text(GTK_ENTRY(name_entry));
 
-                        strncpy(temp, remote_path, MAXLEN-1);
+                        arr_strlcpy(temp, remote_path);
                         if (strlen(remote_path) != 1) {
-                                strncat(temp, "\\", MAXLEN-1);
+                                arr_strlcat(temp, "\\");
                         }
-                        strncat(temp, text, MAXLEN-1);
+                        arr_strlcat(temp, text);
 
                         if (strlen(text)) {
-                                strncpy(dest_file, remote_path, MAXLEN-1);
+                                arr_strlcpy(dest_file, remote_path);
                                 if (strlen(remote_path) != 1) {
-                                        strncat(dest_file, "\\", MAXLEN-1);
+                                        arr_strlcat(dest_file, "\\");
                                 }
-                                strncat(dest_file, remote_item, MAXLEN-1);
+                                arr_strlcat(dest_file, remote_item);
 
                                 ifp_rename(&ifpdev, dest_file, temp);
                                 aifp_update_info();
@@ -435,11 +435,11 @@ aifp_remove_item_cb (GtkButton *button, gpointer user_data) {
         if (strncmp(remote_item, PARENTDIR, 2)) {
 
                 if (remote_type == TYPE_DIR) {
-                        sprintf(temp, _("Directory '%s' will be removed with its entire contents.\n\nDo you want to proceed?"),
-                                remote_item);
+                        arr_snprintf(temp, _("Directory '%s' will be removed with its entire contents.\n\nDo you want to proceed?"),
+                                     remote_item);
                 } else {
-                        sprintf(temp, _("File '%s' will be removed.\n\nDo you want to proceed?"),
-                                remote_item);
+                        arr_snprintf(temp, _("File '%s' will be removed.\n\nDo you want to proceed?"),
+                                     remote_item);
                 }
 
                 response = message_dialog(_("Remove"), aifp_window, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO,
@@ -447,11 +447,11 @@ aifp_remove_item_cb (GtkButton *button, gpointer user_data) {
 
                 if (response == GTK_RESPONSE_YES) {
 
-                        strncpy(temp, remote_path, MAXLEN-1);
+                        arr_strlcpy(temp, remote_path);
                         if (strlen(remote_path) != 1) {
-                                strncat(temp, "\\", MAXLEN-1);
+                                arr_strlcat(temp, "\\");
                         }
-                        strncat(temp, remote_item, MAXLEN-1);
+                        arr_strlcat(temp, remote_item);
 
                         if (ifp_is_file (&ifpdev, temp) == TRUE) {
                                 ifp_delete (&ifpdev, temp);
@@ -474,7 +474,7 @@ item_selected (GtkTreeModel *model, GtkTreeIter *iter, gpointer data) {
         int * n = (int *)data;
 
         gtk_tree_model_get (model, iter, COLUMN_NAME, &text, COLUMN_TYPE_SIZE, &type, -1);
-        strncpy(remote_item, text, MAXLEN-1);
+        arr_strlcpy(remote_item, text);
 
         remote_type = TYPE_DIR;
 
@@ -538,7 +538,7 @@ aifp_dump_files(void *context, int type, const char *name, int filesize) {
 
         if (type == IFP_FILE) {
                 gtk_list_store_append(list_store, &iter);
-                sprintf(temp, "%.1f MB", (double)filesize/(1024*1024));
+                arr_snprintf(temp, "%.1f MB", (double)filesize/(1024*1024));
                 gtk_list_store_set(list_store, &iter, 0, name, 1, temp, -1);
         }
 
@@ -605,9 +605,9 @@ aifp_update_info(void) {
         gfloat space;
 
         if (transfer_mode == UPLOAD_MODE) {
-                sprintf(temp, "%d", number_of_songs);
-                sprintf(tmp, _(" (%.1f MB)"), (float)songs_size / (1024*1024));
-                strncat (temp, tmp, MAXLEN-1);
+                arr_snprintf(temp, "%d", number_of_songs);
+                arr_snprintf(tmp, _(" (%.1f MB)"), (float)songs_size / (1024*1024));
+                arr_strlcat(temp, tmp);
                 gtk_label_set_text(GTK_LABEL(label_songs), temp);
         }
 
@@ -616,12 +616,12 @@ aifp_update_info(void) {
 
         ifp_model(&ifpdev, temp, sizeof(temp));
         capacity = ifp_capacity(&ifpdev);
-        sprintf(tmp, _(" (capacity = %.1f MB)"), (float)capacity / (1024*1024));
-        strncat (temp, tmp, MAXLEN-1);
+        arr_snprintf(tmp, _(" (capacity = %.1f MB)"), (float)capacity / (1024*1024));
+        arr_strlcat(temp, tmp);
         gtk_label_set_text(GTK_LABEL(label_model), temp);
 
         freespace = ifp_freespace(&ifpdev);
-        sprintf(temp, _(" Free space (%.1f MB)"), (float)freespace / (1024*1024));
+        arr_snprintf(temp, _(" Free space (%.1f MB)"), (float)freespace / (1024*1024));
 
         space = (float)freespace/capacity;
 
@@ -805,15 +805,15 @@ gchar *npath;
                         if (npath != NULL) {
                                 *npath = '\0';
                                 if (!strlen(remote_path)) {
-                                        strcpy(remote_path, "\\");
+                                        arr_strlcpy(remote_path, "\\");
                                 }
                                 aifp_directory_listing(NULL);
                         }
                 } else {
                         if (strlen(remote_path) != 1) {
-                                strcat(remote_path, "\\");
+                                arr_strlcat(remote_path, "\\");
                         }
-                        strncat(remote_path, remote_item, MAXLEN-1);
+                        arr_strlcat(remote_path, remote_item);
                         aifp_directory_listing(NULL);
                 }
         }
@@ -855,7 +855,7 @@ directory_chooser(char * title, GtkWidget * parent, char * directory) {
 			gtk_widget_destroy(dialog);
 		}
 
-                strncpy(directory, selected_directory, MAXLEN-1);
+                arr_strlcpy(directory, selected_directory);
 		g_free(utf8);
         }
 
@@ -899,7 +899,7 @@ aifp_transfer_files(gint mode) {
         transfer_mode = mode;
         songs_size = 0;
         transfer_active = 0;
-        strcpy(remote_path, "\\");
+        arr_strlcpy(remote_path, "\\");
 
         if (transfer_mode == UPLOAD_MODE) {
                 number_of_songs = aifp_get_number_of_songs();
@@ -921,15 +921,15 @@ aifp_transfer_files(gint mode) {
                 if (k != number_of_songs) {
                         if (k) {
                                 if((number_of_songs-k) == 1) {
-                                        sprintf(temp, _("One song has format unsupported by your player.\n\nDo you want to proceed?"));
+                                        arr_snprintf(temp, _("One song has format unsupported by your player.\n\nDo you want to proceed?"));
                                 } else {
-                                        sprintf(temp, _("%d of %d songs have format unsupported by your player.\n\nDo you want to proceed?"), number_of_songs-k, number_of_songs);
+                                        arr_snprintf(temp, _("%d of %d songs have format unsupported by your player.\n\nDo you want to proceed?"), number_of_songs-k, number_of_songs);
                                 }
                         } else {
                                 if (number_of_songs == 1) {
-                                        sprintf(temp, _("The selected song has format unsupported by your player.\n\nDo you want to proceed?"));
+                                        arr_snprintf(temp, _("The selected song has format unsupported by your player.\n\nDo you want to proceed?"));
                                 } else {
-                                        sprintf(temp, _("None of the selected songs has format supported by your player.\n\nDo you want to proceed?"));
+                                        arr_snprintf(temp, _("None of the selected songs has format supported by your player.\n\nDo you want to proceed?"));
                                 }
                         }
 
@@ -1185,7 +1185,7 @@ aifp_transfer_files(gint mode) {
                 gtk_widget_set_can_focus(local_path_entry, FALSE);
                 gtk_box_pack_start(GTK_BOX(hbox2), local_path_entry, TRUE, TRUE, 2);
                 gtk_editable_set_editable (GTK_EDITABLE(local_path_entry), FALSE);
-                strncpy(dest_dir, options.home, MAXLEN-1);
+                arr_strlcpy(dest_dir, options.home);
                 gtk_entry_set_text(GTK_ENTRY(local_path_entry), dest_dir);
 
                 local_path_browse_button = gui_stock_label_button(_("Browse"), GTK_STOCK_OPEN);
