@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: music_browser.c 1260 2012-10-23 21:53:42Z assworth $
+    $Id$
 */
 
 #include <config.h>
@@ -589,7 +589,7 @@ create_music_browser(void) {
 
 	/* load tree icons */
         if (options.enable_ms_tree_icons) {
-		sprintf(path, "%s/%s", AQUALUNG_DATADIR, "ms-store.png");
+		arr_snprintf(path, "%s/%s", AQUALUNG_DATADIR, "ms-store.png");
 		icon_store = gdk_pixbuf_new_from_file (path, NULL);
 		store_file_load_icons();
 #ifdef HAVE_CDDA
@@ -665,7 +665,7 @@ create_music_browser(void) {
 			    sizeof(target_table) / sizeof(GtkTargetEntry),
 			    GDK_ACTION_COPY);
 
-	snprintf(path, MAXLEN-1, "%s/drag.png", AQUALUNG_DATADIR);
+	arr_snprintf(path, "%s/drag.png", AQUALUNG_DATADIR);
 	if ((pixbuf = gdk_pixbuf_new_from_file(path, NULL)) != NULL) {
 		gtk_drag_source_set_icon_pixbuf(music_tree, pixbuf);
 	}
@@ -832,7 +832,7 @@ music_store_mark_changed(GtkTreeIter * iter) {
 
 	name[0] = '*';
 	name[1] = '\0';
-	strncat(name, pname, MAXLEN-2);
+	arr_strlcat(name, pname);
 	g_free(pname);
 
 	gtk_tree_store_set(music_store, &iter_store, MS_COL_NAME, name, -1);
@@ -926,7 +926,7 @@ music_store_load_all(void) {
 
 		switch (music_store_get_type(store_file)) {
 		case STORE_TYPE_FILE:
-			snprintf(sort, 15, "%03d", i+1);
+			arr_snprintf(sort, "%03d", i+1);
 			store_file_load(store_file, sort);
 			break;
 		}
