@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: plugin.c 1245 2012-02-04 10:33:30Z assworth $
+    $Id$
 */
 
 #include <config.h>
@@ -145,9 +145,9 @@ parse_lrdf_data(void) {
 	lrdf_path[0] = '\0';
 
 	if ((str = getenv("LADSPA_RDF_PATH"))) {
-		snprintf(lrdf_path, MAXLEN-1, "%s:", str);
+		arr_snprintf(lrdf_path, "%s:", str);
 	} else {
-                strncat(lrdf_path, "/usr/local/share/ladspa/rdf:/usr/share/ladspa/rdf:", MAXLEN-1);
+                arr_strlcat(lrdf_path, "/usr/local/share/ladspa/rdf:/usr/share/ladspa/rdf:");
 	}
 
 	for (i = 0; lrdf_path[i] != '\0'; i++) {
@@ -160,7 +160,7 @@ parse_lrdf_data(void) {
 				int c;
 				
 				for (c = 0; c < n; ++c) {
-					snprintf(fileuri, MAXLEN-1, "file://%s/%s", rdf_path, de[c]->d_name);
+					arr_snprintf(fileuri, "file://%s/%s", rdf_path, de[c]->d_name);
 					if (lrdf_read_file(fileuri)) {
 						fprintf(stderr,
 							"warning: could not parse RDF file: %s\n", fileuri);
@@ -177,14 +177,14 @@ parse_lrdf_data(void) {
 
 
 void
-get_ladspa_category(unsigned long plugin_id, char * str) {
+get_ladspa_category(unsigned long plugin_id, char * str, size_t str_size) {
 
         char buf[256];
         lrdf_statement pattern;
 	lrdf_statement * matches1;
 	lrdf_statement * matches2;
 
-        snprintf(buf, 255, "%s%lu", LADSPA_BASE, plugin_id);
+        arr_snprintf(buf, "%s%lu", LADSPA_BASE, plugin_id);
         pattern.subject = buf;
         pattern.predicate = RDF_TYPE;
         pattern.object = 0;
@@ -193,7 +193,7 @@ get_ladspa_category(unsigned long plugin_id, char * str) {
         matches1 = lrdf_matches(&pattern);
 
         if (!matches1) {
-                strncpy(str, "Unknown", MAXLEN-1);
+                g_strlcpy(str, "Unknown", str_size);
 		return;
         }
 
@@ -206,11 +206,11 @@ get_ladspa_category(unsigned long plugin_id, char * str) {
         lrdf_free_statements(matches1);
 
         if (!matches2) {
-                strncpy(str, "Unknown", MAXLEN-1);
+                g_strlcpy(str, "Unknown", str_size);
                 return;
         }
 
-        strncpy(str, matches2->object, MAXLEN-1);
+        g_strlcpy(str, matches2->object, str_size);
         lrdf_free_statements(matches2);
 }
 
@@ -235,7 +235,7 @@ find_plugins(char * path_entry) {
 	n = scandir(path_entry, &de, so_filter, alphasort);
 	if (n >= 0) {
 		for (c = 0; c < n; ++c) {
-			snprintf(lib_name, MAXLEN-1, "%s/%s", path_entry, de[c]->d_name);
+			arr_snprintf(lib_name, "%s/%s", path_entry, de[c]->d_name);
 			library = dlopen(lib_name, RTLD_LAZY);
 			if (library == NULL) {
 				free(de[c]);
@@ -265,11 +265,11 @@ find_plugins(char * path_entry) {
 
 				if ((n_ins == 1 && n_outs == 1) || (n_ins == 2 && n_outs == 2)) {
 					
-					get_ladspa_category(descriptor->UniqueID, category);
-					snprintf(id_str, 31, "%ld", descriptor->UniqueID);
-					snprintf(n_ins_str, 31, "%ld", n_ins);
-					snprintf(n_outs_str, 31, "%ld", n_outs);
-					snprintf(c_str, 31, "%d", k);
+					get_ladspa_category(descriptor->UniqueID, category, CHAR_ARRAY_SIZE(category));
+					arr_snprintf(id_str, "%ld", descriptor->UniqueID);
+					arr_snprintf(n_ins_str, "%ld", n_ins);
+					arr_snprintf(n_outs_str, "%ld", n_outs);
+					arr_snprintf(c_str, "%d", k);
 					
 					gtk_list_store_append(avail_store, &iter);
 					gtk_list_store_set(avail_store, &iter, 0, id_str,
@@ -384,7 +384,7 @@ instantiate(char * filename, int index) {
 		return NULL;
 	}
 
-	strncpy(instance->filename, filename, MAXLEN-1);
+	arr_strlcpy(instance->filename, filename);
 	instance->index = index;
 
 	instance->library = dlopen(filename, RTLD_NOW);
@@ -521,12 +521,12 @@ activate(plugin_instance * instance) {
 
 
 void
-get_bypassed_name(plugin_instance * instance, char * str) {
+get_bypassed_name(plugin_instance * instance, char * str, size_t str_size) {
 
 	if (instance->is_bypassed) {
-		snprintf(str, MAXLEN-1, "(%s)", instance->descriptor->Name);
+		snprintf(str, str_size, "(%s)", instance->descriptor->Name);
 	} else {
-		strncpy(str, instance->descriptor->Name, MAXLEN-1);
+		g_strlcpy(str, instance->descriptor->Name, str_size);
 	}
 }
 
@@ -594,7 +594,7 @@ plugin_bypassed(GtkWidget * widget, gpointer data) {
 
                 gtk_tree_model_get(GTK_TREE_MODEL(running_store), &iter, 0, &name, 1, &gp_instance, -1);
 		if (instance == (plugin_instance *)gp_instance) {
-			get_bypassed_name(instance, bypassed_name);
+			get_bypassed_name(instance, bypassed_name, CHAR_ARRAY_SIZE(bypassed_name));
 			gtk_list_store_set(running_store, &iter, 0, bypassed_name, -1);
 			return;
 		}
@@ -807,7 +807,7 @@ build_plugin_window(plugin_instance * instance) {
         gtk_box_pack_start(GTK_BOX(hbox), widget, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(upper_vbox), hbox, FALSE, FALSE, 2);
 
-	strncpy(maker, plugin->Maker, MAXLEN-1);
+	arr_strlcpy(maker, plugin->Maker);
 	if ((c = strchr(maker, '<')) != NULL)
 		*c = '\0';
 	widget = gtk_label_new(maker);
@@ -827,21 +827,21 @@ build_plugin_window(plugin_instance * instance) {
 		}
 	}
 
-	strcpy(str_inout, "[ ");
+	arr_strlcpy(str_inout, "[ ");
 	if (n_ins == 1) {
-		strcat(str_inout, "1 in");
+		arr_strlcat(str_inout, "1 in");
 	} else {
-		snprintf(str_n, 15, "%d ins", n_ins);
-		strcat(str_inout, str_n);
+		arr_snprintf(str_n, "%d ins", n_ins);
+		arr_strlcat(str_inout, str_n);
 	}
-	strcat(str_inout, " | ");
+	arr_strlcat(str_inout, " | ");
 	if (n_outs == 1) {
-		strcat(str_inout, "1 out");
+		arr_strlcat(str_inout, "1 out");
 	} else {
-		snprintf(str_n, 15, "%d outs", n_outs);
-		strcat(str_inout, str_n);
+		arr_snprintf(str_n, "%d outs", n_outs);
+		arr_strlcat(str_inout, str_n);
 	}
-	strcat(str_inout, " ]");
+	arr_strlcat(str_inout, " ]");
  
 	widget = gtk_label_new(str_inout);
 	hbox = gtk_hbox_new(FALSE, 0);
@@ -1470,7 +1470,7 @@ foreach_plugin_to_add(GtkTreeModel * model, GtkTreePath * path, GtkTreeIter * it
 	
 	sscanf(str_n_ins, "%d", &n_ins);
 	sscanf(str_n_outs, "%d", &n_outs);
-	strncpy(filename, str_filename, MAXLEN-1);
+	arr_strlcpy(filename, str_filename);
 	sscanf(str_index, "%d", &index);
 	
 	if (((n_ins == 1) && (n_outs == 1)) ||
@@ -1488,7 +1488,7 @@ foreach_plugin_to_add(GtkTreeModel * model, GtkTreePath * path, GtkTreeIter * it
 			activate(instance);
 			build_plugin_window(instance);
 			
-			get_bypassed_name(instance, bypassed_name);
+			get_bypassed_name(instance, bypassed_name, CHAR_ARRAY_SIZE(bypassed_name));
 			added_plugin = 1; /* so resort handler will not do any harm */
 			gtk_list_store_append(running_store, &running_iter);
 			gtk_list_store_set(running_store, &running_iter,
@@ -2024,7 +2024,7 @@ save_plugin_data(void) {
         char str[32];
 
 
-        sprintf(plugin_file, "%s/plugin.xml", options.confdir);
+        arr_snprintf(plugin_file, "%s/plugin.xml", options.confdir);
 
         doc = xmlNewDoc((const xmlChar*) "1.0");
         root = xmlNewNode(NULL, (const xmlChar*) "aqualung_plugin");
@@ -2039,10 +2039,10 @@ save_plugin_data(void) {
 
 		xmlNewTextChild(plugin_node, NULL, (const xmlChar*) "filename", (xmlChar*) instance->filename);
 
-		snprintf(str, 31, "%d", instance->index);
+		arr_snprintf(str, "%d", instance->index);
 		xmlNewTextChild(plugin_node, NULL, (const xmlChar*) "index", (xmlChar*) str);
 
-		snprintf(str, 31, "%d", instance->is_bypassed);
+		arr_snprintf(str, "%d", instance->is_bypassed);
 		xmlNewTextChild(plugin_node, NULL, (const xmlChar*) "is_bypassed", (xmlChar*) str);
 
                 for (k = 0; k < MAX_KNOBS && k < instance->descriptor->PortCount; ++k) {
@@ -2054,16 +2054,16 @@ save_plugin_data(void) {
 
 			port_node = xmlNewTextChild(plugin_node, NULL, (const xmlChar*) "port", NULL);
 
-			snprintf(str, 31, "%d", k);
+			arr_snprintf(str, "%d", k);
 			xmlNewTextChild(port_node, NULL, (const xmlChar*) "index", (xmlChar*) str);
 
-			snprintf(str, 31, "%f", instance->knobs[k]);
+			arr_snprintf(str, "%f", instance->knobs[k]);
 			xmlNewTextChild(port_node, NULL, (const xmlChar*) "value", (xmlChar*) str);
 		}
                 ++i;
         }
 
-        sprintf(tmpname, "%s/plugin.xml.temp", options.confdir);
+        arr_snprintf(tmpname, "%s/plugin.xml.temp", options.confdir);
         xmlSaveFormatFile(tmpname, doc, 1);
 	xmlFreeDoc(doc);
 
@@ -2113,7 +2113,7 @@ parse_plugin(xmlDocPtr doc, xmlNodePtr cur) {
                 if ((!xmlStrcmp(cur->name, (const xmlChar *)"filename"))) {
                         key = xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
                         if (key != NULL)
-                                strncpy(filename, (char *) key, MAXLEN-1);
+                                arr_strlcpy(filename, (char *) key);
                         xmlFree(key);
                         if (filename[0] == '\0') {
                                 fprintf(stderr, "Error in XML aqualung_plugin: "
@@ -2180,7 +2180,7 @@ parse_plugin(xmlDocPtr doc, xmlNodePtr cur) {
 			instance->is_bypassed = is_bypassed;
 			build_plugin_window(instance);
 			
-			get_bypassed_name(instance, bypassed_name);
+			get_bypassed_name(instance, bypassed_name, CHAR_ARRAY_SIZE(bypassed_name));
 			added_plugin = 1; /* so resort handler will not do any harm */
 			gtk_list_store_append(running_store, &running_iter);
 			gtk_list_store_set(running_store, &running_iter,
@@ -2202,7 +2202,7 @@ load_plugin_data(void) {
         char plugin_file[MAXLEN];
         FILE * f;
 
-        sprintf(plugin_file, "%s/plugin.xml", options.confdir);
+        arr_snprintf(plugin_file, "%s/plugin.xml", options.confdir);
 
         if ((f = fopen(plugin_file, "rt")) == NULL) {
                 fprintf(stderr, "No plugin.xml -- creating empty one: %s\n", plugin_file);
