@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: podcast.c 1286 2014-04-27 20:50:41Z tszilagyi $
+    $Id$
 */
 
 #include <config.h>
@@ -62,14 +62,14 @@ podcast_new(void) {
 }
 
 void
-podcast_get_display_name(podcast_t * podcast, char * buf) {
+podcast_get_display_name(podcast_t * podcast, char * buf, size_t buf_size) {
 
 	if (podcast->author != NULL && podcast->title != NULL) {
-		snprintf(buf, MAXLEN-1, "%s: %s", podcast->author, podcast->title);
+		snprintf(buf, buf_size, "%s: %s", podcast->author, podcast->title);
 	} else if (podcast->title != NULL) {
-		strncpy(buf, podcast->title, MAXLEN-1);
+		g_strlcpy(buf, podcast->title, buf_size);
 	} else {
-		strncpy(buf, _("Untitled"), MAXLEN-1);
+		g_strlcpy(buf, _("Untitled"), buf_size);
 	}
 }
 
@@ -661,7 +661,7 @@ podcast_parse(podcast_t * podcast, GSList ** list) {
 	char * file;
 
 	file = podcast_file_from_url(podcast->url);
-	snprintf(filename, MAXLEN-1, "%s/.%s", podcast->dir, file);
+	arr_snprintf(filename, "%s/.%s", podcast->dir, file);
 	free(file);
 
 	if (podcast_generic_download(podcast, podcast->url, filename, NULL, NULL) < 0) {
@@ -727,7 +727,7 @@ podcast_item_download(podcast_download_t * pd, GSList ** list, GSList * node) {
 
 
 	file = podcast_file_from_url(item->url);
-	snprintf(path, MAXLEN-1, "%s/%s", pd->podcast->dir, file);
+	arr_snprintf(path, "%s/%s", pd->podcast->dir, file);
 	free(file);
 
 	pd->ncurrent++;
@@ -867,7 +867,7 @@ podcast_update(podcast_t * podcast) {
 
 	if (podcast->state == PODCAST_STATE_IDLE || podcast->state == PODCAST_STATE_PENDING) {
 
-		AQUALUNG_THREAD_DECLARE(thread_id);
+		AQUALUNG_THREAD_DECLARE(thread_id)
 
 		podcast->state = PODCAST_STATE_UPDATE;
 		AQUALUNG_THREAD_CREATE(thread_id, NULL, podcast_update_thread, podcast);
