@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: ports.c 1245 2012-02-04 10:33:30Z assworth $
+    $Id$
 */
 
 #include <config.h>
@@ -63,7 +63,7 @@ GtkTreeViewColumn * column_out_R;
 int n_clients;
 GtkListStore * store_out_nb[MAX_JACK_CLIENTS];
 
-gint timeout_tag;
+guint ports_timeout_tag;
 
 int out_selector = 0;
 
@@ -197,7 +197,7 @@ tree_out_nb_selection_changed(GtkObject * tree, gpointer * data) {
 
                 gtk_tree_model_get(model, &iter, 0, &str, -1);
 		label = gtk_label_get_text(GTK_LABEL(nb_out_labels[GPOINTER_TO_INT(data)]));
-		sprintf(fullname, "%s:%s", label, str);
+		arr_snprintf(fullname, "%s:%s", label, str);
 		g_free(str);
 
 		if (out_selector == 0) {
@@ -242,7 +242,7 @@ tree_out_L_selection_changed(GtkTreeSelection * selection, gpointer * data) {
 			fprintf(stderr, "ERROR: jack_disconnect() returned %d\n", res);
 		}
 		g_free(str);
-		timeout_tag = aqualung_timeout_add(100, ports_timeout_callback, GINT_TO_POINTER(1));
+		ports_timeout_tag = aqualung_timeout_add(100, ports_timeout_callback, GINT_TO_POINTER(1));
         }
 }
 
@@ -262,7 +262,7 @@ tree_out_R_selection_changed(GtkTreeSelection *selection, gpointer * data) {
 			fprintf(stderr, "ERROR: jack_disconnect() returned %d\n", res);
 		}
 		g_free(str);
-		timeout_tag = aqualung_timeout_add(100, ports_timeout_callback, (gpointer)2);
+		ports_timeout_tag = aqualung_timeout_add(100, ports_timeout_callback, (gpointer)2);
         }
 }
 
@@ -408,7 +408,7 @@ setup_notebook_out(void) {
 				gtk_list_store_append(store_out_nb[n_clients], &iter);
 				gtk_list_store_set(store_out_nb[n_clients], &iter, 0, port_name, -1);
 			}
-			strcpy(client_name_prev, client_name);
+			arr_strlcpy(client_name_prev, client_name);
 			i++;
 		}
 		free(ports_out);
