@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: search.c 1292 2014-05-02 12:29:01Z tszilagyi $
+    $Id$
 */
 
 #include <config.h>
@@ -189,9 +189,9 @@ search_button_clicked(GtkWidget * widget, gpointer data) {
 	}
 
 	if (exactonly) {
-		strcpy(key, key_string);
+		arr_strlcpy(key, key_string);
 	} else {
-		snprintf(key, MAXLEN-1, "*%s*", key_string);
+		arr_snprintf(key, "*%s*", key_string);
 	}
 
 	pattern = g_pattern_spec_new(key);
