@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: store_cdda.c 1292 2014-05-02 12:29:01Z tszilagyi $
+    $Id$
 */
 
 #include <config.h>
@@ -73,7 +73,6 @@ GtkWidget * cdda_record__addlist_albummode;
 GtkWidget * cdda_record__separator1;
 #ifdef HAVE_CDDB
 GtkWidget * cdda_record__cddb;
-GtkWidget * cdda_record__cddb_submit;
 #endif /* HAVE_CDDB */
 #ifdef HAVE_TRANSCODING
 GtkWidget * cdda_record__rip;
@@ -188,7 +187,7 @@ cdda_drive_info(cdda_drive_t * drive) {
 	cdio_get_drive_cap(cdio, &read_cap, &write_cap, &misc_cap);
 	cdio_destroy(cdio);
 
-	snprintf(str, MAXLEN-1, "%s [%s]", _("Drive info"), cdda_displayed_device_path(drive->device_path));
+	arr_snprintf(str, "%s [%s]", _("Drive info"), cdda_displayed_device_path(drive->device_path));
 
         dialog = gtk_dialog_new_with_buttons(str,
 					     GTK_WINDOW(browser_window),
@@ -585,23 +584,6 @@ cdda_record__cddb_cb(gpointer data) {
 	}
 }
 
-void
-cdda_record__cddb_submit_cb(gpointer data) {
-
-	GtkTreeIter iter;
-
-	if (gtk_tree_selection_get_selected(music_select, NULL, &iter)) {
-
-		int ntracks;
-		int * frames;
-		int length;
-
-		if (cddb_init_query_data(&iter, &ntracks, &frames, &length) == 0) {
-			cddb_start_submit(&iter, ntracks, frames, length);
-		}
-	}
-}
-
 void
 cdda_record_auto_query_cddb(GtkTreeIter * drive_iter) {
 
@@ -651,17 +633,17 @@ cdda_track_addlist_iter(GtkTreeIter iter_track, playlist_t * pl, GtkTreeIter * p
 		gtk_tree_model_get(GTK_TREE_MODEL(pl->store), piter, PL_COL_DATA, &pdata, -1);
 		if (pdata->artist && pdata->album &&
 		    !strcmp(pdata->artist, drive->disc.artist_name) && !strcmp(pdata->album, drive->disc.record_name)) {
-			strcpy(list_str, track_name);
+			arr_strlcpy(list_str, track_name);
 		} else {
-			make_title_string(list_str, options.title_format, drive->disc.artist_name,
-					  drive->disc.record_name, track_name);
+			make_title_string(list_str, CHAR_ARRAY_SIZE(list_str), options.title_format,
+					  drive->disc.artist_name, drive->disc.record_name, track_name);
 		}
 	} else {
-		make_title_string(list_str, options.title_format, drive->disc.artist_name,
-				  drive->disc.record_name, track_name);
+		make_title_string(list_str, CHAR_ARRAY_SIZE(list_str), options.title_format,
+				  drive->disc.artist_name, drive->disc.record_name, track_name);
 	}
 
-	time2time(data->duration, duration_str);
+	time2time(data->duration, duration_str, CHAR_ARRAY_SIZE(duration_str));
 
 	if ((pldata = playlist_data_new()) == NULL) {
 		return 0;
@@ -717,7 +699,7 @@ cdda_record_addlist_iter(GtkTreeIter iter_record, playlist_t * pl, GtkTreeIter *
 
 		gtk_tree_model_get(GTK_TREE_MODEL(music_store), &iter_record, MS_COL_DATA, &drive, -1);
 
-		snprintf(list_str, MAXLEN-1, "%s: %s", drive->disc.artist_name, drive->disc.record_name);
+		arr_snprintf(list_str, "%s: %s", drive->disc.artist_name, drive->disc.record_name);
 
 		pldata->artist = strdup(drive->disc.artist_name);
 		pldata->album = strdup(drive->disc.record_name);
@@ -745,7 +727,7 @@ cdda_record_addlist_iter(GtkTreeIter iter_record, playlist_t * pl, GtkTreeIter *
 	if (album_mode) {
 		char duration_str[MAXLEN];
 		pldata->duration = record_duration;
-		time2time(record_duration, duration_str);
+		time2time(record_duration, duration_str, CHAR_ARRAY_SIZE(duration_str));
 		gtk_tree_store_set(pl->store, &list_iter, PL_COL_DURA, duration_str, -1);
 	}
 }
@@ -1039,32 +1021,32 @@ set_status_bar_info(GtkTreeIter * tree_iter, GtkLabel * statusbar) {
 	switch (depth) {
 	case 3:
 		track_status_bar_info(model, tree_iter, &length);
-		sprintf(str, "%s ", name);
+		arr_snprintf(str, "%s ", name);
 		break;
 	case 2:
 		record_status_bar_info(model, tree_iter, &length, &ntrack, &nrecord);
 		if (nrecord == 0) {
-			sprintf(str, "%s:  %s ", _("CD Audio"), name);
+			arr_snprintf(str, "%s:  %s ", _("CD Audio"), name);
 		} else {
-			sprintf(str, "%s:  %d %s ", name,
-				ntrack, (ntrack == 1) ? _("track") : _("tracks"));
+			arr_snprintf(str, "%s:  %d %s ", name,
+				     ntrack, (ntrack == 1) ? _("track") : _("tracks"));
 		}
 		break;
 	case 1:
 		store_status_bar_info(model, tree_iter, &length, &ntrack, &nrecord, &ndrive);
-		sprintf(str, "%s:  %d %s, %d %s, %d %s ", name,
-			ndrive, (ndrive == 1) ? _("drive") : _("drives"),
-			nrecord, (nrecord == 1) ? _("record") : _("records"),
-			ntrack, (ntrack == 1) ? _("track") : _("tracks"));
+		arr_snprintf(str, "%s:  %d %s, %d %s, %d %s ", name,
+			     ndrive, (ndrive == 1) ? _("drive") : _("drives"),
+			     nrecord, (nrecord == 1) ? _("record") : _("records"),
+			     ntrack, (ntrack == 1) ? _("track") : _("tracks"));
 		break;
 	}
 
 	g_free(name);
 
 	if (length > 0.0f) {
-		time2time(length, length_str);
-		sprintf(tmp, " [%s] ", length_str);
-		strcat(str, tmp);
+		time2time(length, length_str, CHAR_ARRAY_SIZE(length_str));
+		arr_snprintf(tmp, " [%s] ", length_str);
+		arr_strlcat(str, tmp);
 	}
 
 
@@ -1092,7 +1074,6 @@ set_popup_sensitivity(GtkTreePath * path) {
 
 #ifdef HAVE_CDDB
 		gtk_widget_set_sensitive(cdda_record__cddb, val_cdda);
-		gtk_widget_set_sensitive(cdda_record__cddb_submit, val_cdda);
 #endif /* HAVE_CDDB */
 
 #ifdef HAVE_TRANSCODING
@@ -1260,11 +1241,11 @@ store_cdda_load_icons(void) {
 
 	char path[MAXLEN];
 
-	sprintf(path, "%s/%s", AQUALUNG_DATADIR, "ms-cdda.png");
+	arr_snprintf(path, "%s/%s", AQUALUNG_DATADIR, "ms-cdda.png");
 	icon_cdda = gdk_pixbuf_new_from_file (path, NULL);
-	sprintf(path, "%s/%s", AQUALUNG_DATADIR, "ms-cdda-disk.png");
+	arr_snprintf(path, "%s/%s", AQUALUNG_DATADIR, "ms-cdda-disk.png");
 	icon_cdda_disc = gdk_pixbuf_new_from_file (path, NULL);
-	sprintf(path, "%s/%s", AQUALUNG_DATADIR, "ms-cdda-nodisk.png");
+	arr_snprintf(path, "%s/%s", AQUALUNG_DATADIR, "ms-cdda-nodisk.png");
 	icon_cdda_nodisc = gdk_pixbuf_new_from_file (path, NULL);
 }
 
@@ -1281,7 +1262,6 @@ store_cdda_create_popup_menu(void) {
 	cdda_record__separator1 = gtk_separator_menu_item_new();
 #ifdef HAVE_CDDB
 	cdda_record__cddb = gtk_menu_item_new_with_label(_("CDDB query for this CD..."));
-	cdda_record__cddb_submit = gtk_menu_item_new_with_label(_("Submit CD to CDDB database..."));
 #endif /* HAVE_CDDB */
 #ifdef HAVE_TRANSCODING
 	cdda_record__rip = gtk_menu_item_new_with_label(_("Rip CD..."));
@@ -1296,7 +1276,6 @@ store_cdda_create_popup_menu(void) {
 	gtk_menu_shell_append(GTK_MENU_SHELL(cdda_record_menu), cdda_record__separator1);
 #ifdef HAVE_CDDB
 	gtk_menu_shell_append(GTK_MENU_SHELL(cdda_record_menu), cdda_record__cddb);
-	gtk_menu_shell_append(GTK_MENU_SHELL(cdda_record_menu), cdda_record__cddb_submit);
 #endif /* HAVE_CDDB */
 #ifdef HAVE_TRANSCODING
 	gtk_menu_shell_append(GTK_MENU_SHELL(cdda_record_menu), cdda_record__rip);
@@ -1310,7 +1289,6 @@ store_cdda_create_popup_menu(void) {
  	g_signal_connect_swapped(G_OBJECT(cdda_record__addlist_albummode), "activate", G_CALLBACK(cdda_record__addlist_albummode_cb), NULL);
 #ifdef HAVE_CDDB
 	g_signal_connect_swapped(G_OBJECT(cdda_record__cddb), "activate", G_CALLBACK(cdda_record__cddb_cb), NULL);
- 	g_signal_connect_swapped(G_OBJECT(cdda_record__cddb_submit), "activate", G_CALLBACK(cdda_record__cddb_submit_cb), NULL);
 #endif /* HAVE_CDDB */
 #ifdef HAVE_TRANSCODING
  	g_signal_connect_swapped(G_OBJECT(cdda_record__rip), "activate", G_CALLBACK(cdda_record__rip_cb), NULL);
@@ -1324,7 +1302,6 @@ store_cdda_create_popup_menu(void) {
 	gtk_widget_show(cdda_record__separator1);
 #ifdef HAVE_CDDB
 	gtk_widget_show(cdda_record__cddb);
-	gtk_widget_show(cdda_record__cddb_submit);
 #endif /* HAVE_CDDB */
 #ifdef HAVE_TRANSCODING
 	gtk_widget_show(cdda_record__rip);
