@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: store_podcast.c 1293 2014-05-04 22:06:57Z tszilagyi $
+    $Id$
 */
 
 #include <config.h>
@@ -232,7 +232,7 @@ podcast_browse_button_clicked(GtkButton * button, gpointer data) {
 				GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
 				FILE_CHOOSER_FILTER_NONE,
 				(GtkWidget *)data,
-				options.podcastdir);
+				options.podcastdir, CHAR_ARRAY_SIZE(options.podcastdir));
 }
 
 void
@@ -358,7 +358,7 @@ podcast_dialog(podcast_t ** podcast, int create) {
 			char dir[MAXLEN];
 			char url[MAXLEN];
 
-			strncpy(url, gtk_entry_get_text(GTK_ENTRY(url_entry)), MAXLEN-1);
+			arr_strlcpy(url, gtk_entry_get_text(GTK_ENTRY(url_entry)));
 			if (url[0] == '\0') {
 				gtk_widget_grab_focus(url_entry);
 				goto display;
@@ -374,10 +374,10 @@ podcast_dialog(podcast_t ** podcast, int create) {
 				return 0;
 			}
 
-			normalize_filename(pdir, dir);
+			normalize_filename(pdir, dir, CHAR_ARRAY_SIZE(dir));
 			(*podcast)->dir = strdup(dir);
 			(*podcast)->url = strdup(url);
-			strncpy(options.podcastdir, dir, MAXLEN-1);
+			arr_strlcpy(options.podcastdir, dir);
 		}
 
 		if (options.podcasts_autocheck || create) {
@@ -443,15 +443,17 @@ podcast_track_addlist_iter(GtkTreeIter iter_track, playlist_t * pl,
 		gtk_tree_model_get(GTK_TREE_MODEL(pl->store), piter, PL_COL_DATA, &pdata, -1);
 		if (pdata->artist && pdata->album && podcast->author && podcast->title &&
 		    !strcmp(pdata->artist, podcast->author) && !strcmp(pdata->album, podcast->title)) {
-			strcpy(list_str, item->title);
+			arr_strlcpy(list_str, item->title);
 		} else {
-			make_title_string(list_str, options.title_format, podcast->author, podcast->title, item->title);
+			make_title_string(list_str, CHAR_ARRAY_SIZE(list_str), options.title_format,
+					  podcast->author, podcast->title, item->title);
 		}
 	} else {
-		make_title_string(list_str, options.title_format, podcast->author, podcast->title, item->title);
+		make_title_string(list_str, CHAR_ARRAY_SIZE(list_str), options.title_format,
+				  podcast->author, podcast->title, item->title);
 	}
 
-	time2time(item->duration, duration_str);
+	time2time(item->duration, duration_str, CHAR_ARRAY_SIZE(duration_str));
 
 	if ((pldata = playlist_data_new()) == NULL) {
 		return 0;
@@ -528,9 +530,9 @@ podcast_feed_addlist_iter(GtkTreeIter iter_record, playlist_t * pl, GtkTreeIter
 
 		gtk_tree_model_get(GTK_TREE_MODEL(music_store), &iter_record, MS_COL_DATA, &podcast, -1);
 
-		snprintf(list_str, MAXLEN-1, "%s: %s",
-			 podcast->author ? podcast->author : _("Podcasts"),
-			 podcast->title);
+		arr_snprintf(list_str, "%s: %s",
+			     podcast->author ? podcast->author : _("Podcasts"),
+			     podcast->title);
 
 		pldata->artist = strndup(podcast->author ? podcast->author : _("Podcasts"), MAXLEN-1);
 		pldata->album = strdup(podcast->title);
@@ -558,7 +560,7 @@ podcast_feed_addlist_iter(GtkTreeIter iter_record, playlist_t * pl, GtkTreeIter
 	if (album_mode) {
 		char duration_str[MAXLEN];
 		pldata->duration = record_duration;
-		time2time(record_duration, duration_str);
+		time2time(record_duration, duration_str, CHAR_ARRAY_SIZE(duration_str));
 		gtk_tree_store_set(pl->store, &list_iter, PL_COL_DURA, duration_str, -1);
 	}
 }
@@ -943,7 +945,7 @@ podcast_store__reorder_cb(gpointer data) {
 		podcast_t * podcast;
 
 		gtk_tree_model_get(GTK_TREE_MODEL(music_store), &pod_iter, MS_COL_DATA, &podcast, -1);
-		podcast_get_display_name(podcast, title);
+		podcast_get_display_name(podcast, title, CHAR_ARRAY_SIZE(title));
 		gtk_list_store_append(store, &list_iter);
 		gtk_list_store_set(store, &list_iter, 0, title, 1, gtk_tree_iter_copy(&pod_iter), -1);
 	}
@@ -961,7 +963,7 @@ podcast_store__reorder_cb(gpointer data) {
 		if (res == GTK_RESPONSE_ACCEPT) {
 			char sort[16];
 
-			snprintf(sort, 15, "%03d", i);
+			arr_snprintf(sort, "%03d", i);
 			gtk_tree_store_set(music_store, iter, MS_COL_SORT, sort, -1);
 		}
 
@@ -1030,8 +1032,8 @@ podcast_track_export(GtkTreeIter * iter_track, export_t * export, char * author,
 		gtk_tree_model_get(GTK_TREE_MODEL(music_store), &iter_podcast, MS_COL_DATA, &podcast, -1);
 	}
 
-	strncpy(artist, (author == NULL) ? podcast->author : author, MAXLEN-1);
-	strncpy(album, (feed == NULL) ? podcast->title : feed, MAXLEN-1);
+	arr_strlcpy(artist, (author == NULL) ? podcast->author : author);
+	arr_strlcpy(album, (feed == NULL) ? podcast->title : feed);
 
 	export_append_item(export, item->file, artist, album, title, 0, 0);
 
@@ -1166,7 +1168,7 @@ podcast_iter_set_display_name(podcast_t * podcast, GtkTreeIter * pod_iter) {
 
 	char name_str[MAXLEN];
 
-	podcast_get_display_name(podcast, name_str);
+	podcast_get_display_name(podcast, name_str, CHAR_ARRAY_SIZE(name_str));
 	gtk_tree_store_set(music_store, pod_iter, MS_COL_NAME, name_str, -1);
 }
 
@@ -1200,7 +1202,7 @@ store_podcast_update_podcast_download_cb(gpointer data) {
 		return FALSE;
 	}
 
-	snprintf(name_str, MAXLEN-1, _("Downloading %d/%d (%d%%) ..."), pd->ncurrent, pd->ndownloads, pd->percent);
+	arr_snprintf(name_str, _("Downloading %d/%d (%d%%) ..."), pd->ncurrent, pd->ndownloads, pd->percent);
 	gtk_tree_store_set(music_store, &pod_iter, MS_COL_NAME, name_str, -1);
 
 	return FALSE;
@@ -1219,7 +1221,7 @@ store_podcast_add_item_cb(gpointer data) {
 		return FALSE;
 	}
 
-	snprintf(sort, 15, "%014lld", 10000000000LL - pt->item->date);
+	arr_snprintf(sort, "%014lld", 10000000000LL - pt->item->date);
 
 	gtk_tree_store_append(music_store, &iter, &pod_iter);
 	gtk_tree_store_set(music_store, &iter,
@@ -1402,32 +1404,32 @@ set_status_bar_info(GtkTreeIter * tree_iter, GtkLabel * statusbar) {
 	switch (depth) {
 	case 3:
 		item_status_bar_info(model, tree_iter, &size, &length, &nnewitem);
-		sprintf(str, "%s ", name);
+		arr_snprintf(str, "%s ", name);
 		break;
 	case 2:
 		gtk_tree_model_get(model, tree_iter, MS_COL_DATA, &podcast, -1);
-		podcast_get_display_name(podcast, tmp);
+		podcast_get_display_name(podcast, tmp, CHAR_ARRAY_SIZE(tmp));
 		feed_status_bar_info(model, tree_iter, &size, &length, &nnewitem, &nitem);
 		if (nnewitem > 0) {
-			sprintf(str, "%s:  %d %s, %d %s ", tmp,
-				nitem, (nitem == 1) ? _("item") : _("items"),
-				nnewitem, (nnewitem == 1) ? _("new item") : _("new items"));
+			arr_snprintf(str, "%s:  %d %s, %d %s ", tmp,
+				     nitem, (nitem == 1) ? _("item") : _("items"),
+				     nnewitem, (nnewitem == 1) ? _("new item") : _("new items"));
 		} else {
-			sprintf(str, "%s:  %d %s ", tmp,
-				nitem, (nitem == 1) ? _("item") : _("items"));
+			arr_snprintf(str, "%s:  %d %s ", tmp,
+				     nitem, (nitem == 1) ? _("item") : _("items"));
 		}
 		break;
 	case 1:
 		store_status_bar_info(model, tree_iter, &size, &length, &nnewitem, &nitem, &nfeed);
 		if (nnewitem > 0) {
-			sprintf(str, "%s:  %d %s, %d %s, %d %s ", name,
-				nfeed, (nfeed == 1) ? _("feed") : _("feeds"),
-				nitem, (nitem == 1) ? _("item") : _("items"),
-				nnewitem, (nnewitem == 1) ? _("new item") : _("new items"));
+			arr_snprintf(str, "%s:  %d %s, %d %s, %d %s ", name,
+				     nfeed, (nfeed == 1) ? _("feed") : _("feeds"),
+				     nitem, (nitem == 1) ? _("item") : _("items"),
+				     nnewitem, (nnewitem == 1) ? _("new item") : _("new items"));
 		} else {
-			sprintf(str, "%s:  %d %s, %d %s ", name,
-				nfeed, (nfeed == 1) ? _("feed") : _("feeds"),
-				nitem, (nitem == 1) ? _("item") : _("items"));
+			arr_snprintf(str, "%s:  %d %s, %d %s ", name,
+				     nfeed, (nfeed == 1) ? _("feed") : _("feeds"),
+				     nitem, (nitem == 1) ? _("item") : _("items"));
 		}
 		break;
 	}
@@ -1435,25 +1437,25 @@ set_status_bar_info(GtkTreeIter * tree_iter, GtkLabel * statusbar) {
 	g_free(name);
 
 	if (length > 0.0f || nitem == 0) {
-		time2time(length, length_str);
-		sprintf(tmp, " [%s] ", length_str);
+		time2time(length, length_str, CHAR_ARRAY_SIZE(length_str));
+		arr_snprintf(tmp, " [%s] ", length_str);
 	} else {
-		strcpy(tmp, " [N/A] ");
+		arr_strlcpy(tmp, " [N/A] ");
 	}
 
-	strcat(str, tmp);
+	arr_strlcat(str, tmp);
 
 	if (options.ms_statusbar_show_size) {
 		if (size > 1024 * 1024) {
-			sprintf(tmp, " (%.1f GB) ", size / (1024 * 1024));
+			arr_snprintf(tmp, " (%.1f GB) ", size / (1024 * 1024));
 		} else if (size > 1024) {
-			sprintf(tmp, " (%.1f MB) ", size / 1024);
+			arr_snprintf(tmp, " (%.1f MB) ", size / 1024);
 		} else if (size > 0 || nitem == 0) {
-			sprintf(tmp, " (%.1f KB) ", size);
+			arr_snprintf(tmp, " (%.1f KB) ", size);
 		} else {
-			strcpy(tmp, " (N/A) ");
+			arr_strlcpy(tmp, " (N/A) ");
 		}
-		strcat(str, tmp);
+		arr_strlcat(str, tmp);
 	}
 
 	gtk_label_set_text(statusbar, str);
@@ -1512,7 +1514,7 @@ add_path_to_playlist(GtkTreePath * path, GtkTreeIter * piter, int new_tab) {
 			podcast_t * podcast;
 
 			gtk_tree_model_get(GTK_TREE_MODEL(music_store), &iter, MS_COL_DATA, &podcast, -1);
-			podcast_get_display_name(podcast, name);
+			podcast_get_display_name(podcast, name, CHAR_ARRAY_SIZE(name));
 			playlist_tab_new_if_nonempty(name);
 		} else {
 			char * name;
@@ -1650,9 +1652,9 @@ store_podcast_load_icons(void) {
 
 	char path[MAXLEN];
 
-	sprintf(path, "%s/%s", AQUALUNG_DATADIR, "ms-podcast.png");
+	arr_snprintf(path, "%s/%s", AQUALUNG_DATADIR, "ms-podcast.png");
 	icon_podcasts = gdk_pixbuf_new_from_file (path, NULL);
-	sprintf(path, "%s/%s", AQUALUNG_DATADIR, "ms-feed.png");
+	arr_snprintf(path, "%s/%s", AQUALUNG_DATADIR, "ms-feed.png");
 	icon_feed = gdk_pixbuf_new_from_file (path, NULL);
 }
 
@@ -1995,7 +1997,7 @@ store_podcast_save(void) {
 		save_podcast(doc, root, &pod_iter);
 	}
 
-	snprintf(file, MAXLEN-1, "%s/podcast.xml", options.confdir);
+	arr_snprintf(file, "%s/podcast.xml", options.confdir);
 	xmlSaveFormatFile(file, doc, 1);
 	xmlFreeDoc(doc);
 
@@ -2031,7 +2033,7 @@ parse_podcast_item(xmlDocPtr doc, xmlNodePtr cur, GtkTreeIter * pod_iter, podcas
 		xml_load_str_dup(doc, cur, "title", &item->title);
 		xml_load_str_dup(doc, cur, "desc", &item->desc);
 		xml_load_str_dup(doc, cur, "url", &item->url);
-		xml_load_str(doc, cur, "sort", sort);
+		xml_load_str(doc, cur, "sort", sort, CHAR_ARRAY_SIZE(sort));
 
 		xml_load_int(doc, cur, "new", &item->new);
 		xml_load_float(doc, cur, "duration", &item->duration);
@@ -2098,7 +2100,7 @@ store_podcast_load(void) {
 	xmlNodePtr cur;
 	char file[MAXLEN];
 	
-	snprintf(file, MAXLEN-1, "%s/podcast.xml", options.confdir);
+	arr_snprintf(file, "%s/podcast.xml", options.confdir);
 	if (!g_file_test(file, G_FILE_TEST_EXISTS)) {
 		return;
 	}
@@ -2148,7 +2150,8 @@ store_model_func(GtkTreeModel * model, GtkTreeIter iter, char**name, char**file)
 	gtk_tree_model_get(model, &iter, MS_COL_DATA, &item, -1);
 	gtk_tree_model_iter_parent(model, &pod_iter, &iter);
 	gtk_tree_model_get(model, &pod_iter, MS_COL_DATA, &podcast, -1);
-	make_title_string(buf, options.title_format, podcast->author, podcast->title, item->title);
+	make_title_string(buf, CHAR_ARRAY_SIZE(buf), options.title_format,
+			  podcast->author, podcast->title, item->title);
 
 	*name = strndup(buf, MAXLEN-1);
 	*file = strdup(item->file);
