@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: utils_gui.c 1295 2014-05-04 22:07:31Z tszilagyi $
+    $Id$
 */
 
 #include <config.h>
@@ -499,7 +499,7 @@ assign_audio_fc_filters(GtkFileChooser * fc) {
         gtk_file_filter_set_name(filter, _("LAVC audio/video files"));
 	{
 		char * valid_ext_lavc[] = {
-			"aac", "ac3", "asf", "avi", "mpeg", "mpg", "mp3", "ra",
+			"aac", "ac3", "asf", "avi", "m4a", "mpeg", "mpg", "mp3", "ra",
 			"wav", "wma", "wv", NULL };
 		build_filter_from_extensions(filter, filter_all, valid_ext_lavc);
 	}
@@ -529,7 +529,7 @@ assign_fc_filters(GtkFileChooser * fc, int filter) {
 
 GSList *
 file_chooser(char * title, GtkWidget * parent, GtkFileChooserAction action, int filter,
-	     gint multiple, char * destpath) {
+	     gint multiple, char * destpath, size_t destpath_size) {
 
         GtkWidget * dialog;
 	GSList * files = NULL;
@@ -561,9 +561,9 @@ file_chooser(char * title, GtkWidget * parent, GtkFileChooserAction action, int
 
         if (aqualung_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT) {
 
-		strncpy(destpath,
-			gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog)),
-			MAXLEN-1);
+		g_strlcpy(destpath,
+			  gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog)),
+			  destpath_size);
 
 		files = gtk_file_chooser_get_filenames(GTK_FILE_CHOOSER(dialog));
         }
@@ -575,7 +575,7 @@ file_chooser(char * title, GtkWidget * parent, GtkFileChooserAction action, int
 
 void
 file_chooser_with_entry(char * title, GtkWidget * parent, GtkFileChooserAction action, int filter,
-			GtkWidget * entry, char * destpath) {
+			GtkWidget * entry, char * destpath, size_t destpath_size) {
 
         GtkWidget * dialog;
 	const gchar * selected_filename = gtk_entry_get_text(GTK_ENTRY(entry));
@@ -602,10 +602,10 @@ file_chooser_with_entry(char * title, GtkWidget * parent, GtkFileChooserAction a
 			return;
 		}
 
-		normalize_filename(filename, path);
+		normalize_filename(filename, path, CHAR_ARRAY_SIZE(path));
 		g_free(filename);
 	} else {
-		strncpy(path, destpath, MAXLEN-1);
+		arr_strlcpy(path, destpath);
 	}
 
 	gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(dialog), path);
@@ -633,7 +633,7 @@ file_chooser_with_entry(char * title, GtkWidget * parent, GtkFileChooserAction a
 
 		gtk_entry_set_text(GTK_ENTRY(entry), utf8);
 
-                strncpy(destpath, selected_filename, MAXLEN-1);
+		g_strlcpy(destpath, selected_filename, destpath_size);
 		g_free(utf8);
         }
 
@@ -809,9 +809,9 @@ set_option_from_spin(GtkWidget * widget, int * opt) {
 }
 
 void
-set_option_from_entry(GtkWidget * widget, char * opt, int n) {
+set_option_from_entry(GtkWidget * widget, char * opt, size_t opt_size) {
 
-	strncpy(opt, gtk_entry_get_text(GTK_ENTRY(widget)), n-1);
+	g_strlcpy(opt, gtk_entry_get_text(GTK_ENTRY(widget)), opt_size);
 }
 
 void
